@@ -2,7 +2,7 @@
  *     gtkatlantic - the gtk+ monopd client, enjoy network monopoly games
  *
  *
- *  Copyright (C) 2002-2004 Rochet Sylvain
+ *  Copyright (C) 2002-2010 Rochet Sylvain
  *
  *  gtkatlantic is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -130,7 +130,7 @@ void Callback_GetGame_Unselect(GtkWidget* clist, gint row)  {
 /* **** Join/create a game */
 void Callback_ConnectButton(GtkWidget* clist)  {
 
-	guint16 connectid;
+	gint32 connectid;
 	gchar *text;
 
 	if(!global->selected_host) return;
@@ -198,7 +198,7 @@ void Callback_EnterButton(GtkWidget* button)  {
 /* *** send data to server */
 void Callback_SendButton(GtkWidget* Button, GtkWidget *entry) {
 
-	guchar *tmp, *tmp2;
+	gchar *tmp, *tmp2;
 
 	tmp = g_strdup( gtk_entry_get_text( GTK_ENTRY(entry) ) );
 	g_strstrip(tmp);
@@ -277,7 +277,7 @@ void CallBack_destroy_window_chat(GtkWidget* widget) {
 /* *** save and apply the config */
 void CallBack_ok_button_configwindow(GtkWidget* widget)  {
 
-	guchar *filename, *errormsg;
+	gchar *filename, *errormsg;
 	FILE *file;
 	guint32 token_animate_speed;
 
@@ -340,7 +340,7 @@ void CallBack_configwindow_destroyed(GtkWidget* widget)  {
 /* *** button command pressed */
 void CallBack_button_command_pressed(GtkWidget* button) {
 
-	guchar *ptr = gtk_object_get_data(GTK_OBJECT(button), "command");
+	gchar *ptr = gtk_object_get_data(GTK_OBJECT(button), "command");
 	client_send(game->connectid, ptr, strlen(ptr) );
 
 	if(! strcmp(ptr, ".E\n") )
@@ -351,7 +351,7 @@ void CallBack_button_command_pressed(GtkWidget* button) {
 /* *** button command pressed */
 void Callback_AuctionButton_Absolute(GtkWidget* button, GtkWidget* entry)  {
 
-	guchar *tosend, *auction, *money;
+	gchar *tosend, *auction, *money;
 
 	auction = gtk_object_get_data(GTK_OBJECT(entry), "auctionid");
 
@@ -372,7 +372,7 @@ void Callback_AuctionButton_Absolute(GtkWidget* button, GtkWidget* entry)  {
 /* *** button command pressed */
 void Callback_AuctionButton_Relative(GtkWidget* button)  {
 
-	guchar *tosend, *auction;
+	gchar *tosend, *auction;
 	gint32 money;
 
 	money = GPOINTER_TO_INT( gtk_object_get_data(GTK_OBJECT(game->BoardCenter), "auction_highbid") )
@@ -389,7 +389,7 @@ void Callback_AuctionButton_Relative(GtkWidget* button)  {
 void Callback_ClicOnEstate(GtkWidget* widget, GdkEventButton *event)  {
 
 	guint8 id = atoi( gtk_object_get_data(GTK_OBJECT(widget), "estateid") );
-	guchar *text;
+	gchar *text;
 
 	if(event->button == 1)  { /* left clic -> build house */
 
@@ -456,7 +456,7 @@ void Callback_ClicOnPlayer(GtkWidget* widget, GdkEvent *event)  {
 /* *** callback clic on estate */
 void CallBack_PopupMenuPlayer(GtkWidget* widget)  {
 
-	guchar *text;
+	gchar *text;
 
 	guint32 id = atoi( gtk_object_get_data(GTK_OBJECT(widget->parent), "playerid") );
 	gchar *action = gtk_object_get_data(GTK_OBJECT(widget), "action");
@@ -498,7 +498,7 @@ void CallBack_PopupMenuPlayer(GtkWidget* widget)  {
 /* *** callback for game option type bool */
 void Callback_toggle_boolean_gameoption(GtkWidget* widget)  {
 
-	guchar *text, *cmd;
+	gchar *text, *cmd;
 
 	if(! widget)  return;
 
@@ -528,7 +528,7 @@ void CallBack_response_changenick_window(GtkWidget* widget, gint response,
 	if(response == GTK_RESPONSE_OK)
 	{
 		GtkWidget *Entry = gtk_object_get_data(GTK_OBJECT(Win), "nickname");
-		guchar *nickname, *sendstr;
+		gchar *nickname, *sendstr;
 
 		nickname = g_strdup( gtk_entry_get_text(GTK_ENTRY( Entry ) )  );
 	
@@ -549,11 +549,11 @@ void CallBack_response_changenick_window(GtkWidget* widget, gint response,
 /* *** callback for the entry menu reconnect */
 void CallBack_menu_reconnect(GtkWidget* widget)  {
 
-	guchar *host, *tmp, *cookie, *filename;
+	gchar *host, *tmp, *cookie, *filename;
 	guint32 port;
 	FILE *file;
 
-	guint16 connectid;
+	gint32 connectid;
 	gchar *text;
 
 	if(global->phase > PHASE_GETGAMES) return;
@@ -605,8 +605,8 @@ void CallBack_menu_reconnect(GtkWidget* widget)  {
 /* *** callback for all trades buttons */
 void CallBack_trade_button(GtkWidget *button)  {
 
-	guchar *sendstr = 0;
-	guchar *command = gtk_object_get_data( GTK_OBJECT(button), "command" );
+	gchar *sendstr = 0;
+	gchar *command = gtk_object_get_data( GTK_OBJECT(button), "command" );
 	guint32 tradeid = atoi( gtk_object_get_data( GTK_OBJECT(button), "tradeid" )  );
 	guint32	tradeslot = get_trade_slot_with_tradeid(tradeid);
 
@@ -646,7 +646,7 @@ void CallBack_trade_button(GtkWidget *button)  {
 /* *** callback for all trade component */
 void CallBack_trade_sub_component(GtkWidget *menuitem)  {
 
-	guchar *component = gtk_object_get_data( GTK_OBJECT(menuitem), "component" );
+	gchar *component = gtk_object_get_data( GTK_OBJECT(menuitem), "component" );
 	guint32 tradeslot = get_trade_slot_with_tradeid( atoi( gtk_object_get_data( GTK_OBJECT(menuitem), "tradeid" )  )  );
 
 	if(!component) return;
@@ -668,7 +668,7 @@ void CallBack_trade_sub_component(GtkWidget *menuitem)  {
 /* *** callback for all update component */
 void CallBack_trade_update_component(GtkWidget *button)  {
 
-	guchar *sendstr;
+	gchar *sendstr;
 	guint32 tradeid, estateid, cardid, target, from, to, tradeslot, money;
 
 	tradeslot = get_trade_slot_with_tradeid( atoi( gtk_object_get_data( GTK_OBJECT(button), "tradeid" )  )  );
@@ -678,8 +678,8 @@ void CallBack_trade_update_component(GtkWidget *button)  {
 
 		case TRADE_CURRENT_COMPONENT_ESTATE:
 
-			estateid = get_estateid_by_estatename( (guchar*)gtk_entry_get_text( gtk_object_get_data( GTK_OBJECT(button), "name_estate" ) )  );
-			target = get_playerid_by_playername( (guchar*)gtk_entry_get_text( gtk_object_get_data( GTK_OBJECT(button), "name_target_player" ) )  );
+			estateid = get_estateid_by_estatename( (gchar*)gtk_entry_get_text( gtk_object_get_data( GTK_OBJECT(button), "name_estate" ) )  );
+			target = get_playerid_by_playername( (gchar*)gtk_entry_get_text( gtk_object_get_data( GTK_OBJECT(button), "name_target_player" ) )  );
 
 			sendstr = g_strdup_printf(".Te%d:%d:%d\n", tradeid, estateid, target);
 			client_send(game->connectid, sendstr, strlen(sendstr));
@@ -688,8 +688,8 @@ void CallBack_trade_update_component(GtkWidget *button)  {
 
 		case TRADE_CURRENT_COMPONENT_MONEY:
 
-			from = get_playerid_by_playername( (guchar*)gtk_entry_get_text( gtk_object_get_data( GTK_OBJECT(button), "name_from_player" ) )  );
-			to = get_playerid_by_playername( (guchar*) gtk_entry_get_text( gtk_object_get_data( GTK_OBJECT(button), "name_to_player" ) )  );
+			from = get_playerid_by_playername( (gchar*)gtk_entry_get_text( gtk_object_get_data( GTK_OBJECT(button), "name_from_player" ) )  );
+			to = get_playerid_by_playername( (gchar*) gtk_entry_get_text( gtk_object_get_data( GTK_OBJECT(button), "name_to_player" ) )  );
 			money = atoi( gtk_entry_get_text( gtk_object_get_data( GTK_OBJECT(button), "amount_money" ) )  );
 
 			sendstr = g_strdup_printf(".Tm%d:%d:%d:%d\n", tradeid, from, to, money);
@@ -700,7 +700,7 @@ void CallBack_trade_update_component(GtkWidget *button)  {
 		case TRADE_CURRENT_COMPONENT_CARD:
 
 			cardid = atoi( gtk_entry_get_text( gtk_object_get_data( GTK_OBJECT(button), "name_card" ) )  );
-			target = get_playerid_by_playername( (guchar*) gtk_entry_get_text( gtk_object_get_data( GTK_OBJECT(button), "name_target_player" ) )  );
+			target = get_playerid_by_playername( (gchar*) gtk_entry_get_text( gtk_object_get_data( GTK_OBJECT(button), "name_target_player" ) )  );
 
 			sendstr = g_strdup_printf(".Tc%d:%d:%d\n", tradeid, cardid, target);
 			client_send(game->connectid, sendstr, strlen(sendstr));
@@ -720,7 +720,7 @@ void CallBack_logo_page_destroyed(GtkWidget *widget)  {
 /* *** callback for the entry menu leave game */
 void CallBack_menu_LeaveGame(GtkWidget* widget)  {
 
-	guchar *sendstr;
+	gchar *sendstr;
 
 	if(global->phase < PHASE_GAMECREATE)  return;
 
@@ -762,7 +762,7 @@ void CallBack_estates_tree(GtkWidget* widget) {
 /* *** callback for the entry menu declare bankrupcy */
 void CallBack_menu_DeclareBankrupcy(GtkWidget* widget)  {
 
-	guchar *sendstr;
+	gchar *sendstr;
 
 	if(global->phase < PHASE_GAMEPLAY) return;
 
@@ -776,7 +776,7 @@ void CallBack_EstateTree_SelectRow(GtkCTree *EstateTree,  GtkCTreeNode *Node)  {
 
 	gchar *data;
 	GtkWidget *parent, *info, *Alignment, *Label;
-	guchar *Text;
+	gchar *Text;
 	gint32 id;
 
 	data = gtk_ctree_node_get_row_data(GTK_CTREE(EstateTree), Node);
