@@ -2,7 +2,7 @@
  *     gtkatlantic - the gtk+ monopd client, enjoy network monopoly games
  *
  *
- *  Copyright (C) 2002-2004 Rochet Sylvain
+ *  Copyright (C) 2002-2010 Rochet Sylvain
  *
  *  gtkatlantic is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -28,9 +28,9 @@
 #include "engine.h"
 
 
-void eng_conv_8_to_mask(guchar * in, guchar * out, guint32 nb_pixel) {
+void eng_conv_8_to_mask(guint8 * in, guint8 * out, gint32 nb_pixel) {
    
-	guint32 i, size_in, size_out;
+	gint32 i, size_in, size_out;
 
 	size_in  = size_out = calc_buf_size(nb_pixel, 1, 8);
 
@@ -42,9 +42,9 @@ void eng_conv_8_to_mask(guchar * in, guchar * out, guint32 nb_pixel) {
 }
 
 
-void eng_conv_16_to_mask(guchar * in, guchar * out, guint32 nb_pixel) {
+void eng_conv_16_to_mask(guint8 * in, guint8 * out, gint32 nb_pixel) {
    
-	guint32 i, size_in, size_out;
+	gint32 i, size_in, size_out;
 
 	size_in  = calc_buf_size(nb_pixel, 1, 16);
 	size_out = calc_buf_size(nb_pixel, 1, 8);
@@ -57,9 +57,9 @@ void eng_conv_16_to_mask(guchar * in, guchar * out, guint32 nb_pixel) {
 }
 
 
-void eng_conv_24_to_mask(guchar * in, guchar * out, guint32 nb_pixel) {
+void eng_conv_24_to_mask(guint8 * in, guint8 * out, gint32 nb_pixel) {
    
-	guint32 i, size_in, size_out;   
+	gint32 i, size_in, size_out;   
 
 	size_in  = calc_buf_size_24(nb_pixel, 1);
 	size_out = calc_buf_size(nb_pixel, 1, 8);
