@@ -2,7 +2,7 @@
  *     gtkatlantic - the gtk+ monopd client, enjoy network monopoly games
  *
  *
- *  Copyright (C) 2002-2004 Rochet Sylvain
+ *  Copyright (C) 2002-2010 Rochet Sylvain
  *
  *  gtkatlantic is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -37,7 +37,7 @@ gint zone_modif[MAX_PIC_PER_FRAME][4], nb_zone_modif;
 /* ---- update all frame */
 void eng_create_frame_all()  {
 
-	guint32 i;
+	gint32 i;
 
 	for(i = 1 ; i <= engine->lastframe ; i++)  {
 
@@ -48,10 +48,9 @@ void eng_create_frame_all()  {
 
 
 /* ---- update a frame */
-void eng_create_frame(guint16 frame_id)  {
+void eng_create_frame(gint32 frame_id)  {
 
-	gint32 i = 0, j = 0;
-	guint32 size = 0;
+	gint32 i = 0, j = 0, size = 0;
 
 	if(!engine->active_frame[frame_id]) return;
 
@@ -235,9 +234,9 @@ void eng_create_frame(guint16 frame_id)  {
 
 
 /* get min/max zone where the pic is displayed before/after change */
-void pic_get_zone_update(guint16 frame_id, guint16 pic_id, gint * x1, gint * y1, gint * x2, gint * y2) {
+void pic_get_zone_update(gint32 frame_id, gint32 pic_id, gint * x1, gint * y1, gint * x2, gint * y2) {
 
-	guint32 x1_old, x1_new, y1_old, y1_new, x2_old, x2_new, y2_old, y2_new;
+	gint32 x1_old, x1_new, y1_old, y1_new, x2_old, x2_new, y2_old, y2_new;
 
 	/* get new coord */
 	x1_new = frame[frame_id]->obj[pic_id]->x;
@@ -299,7 +298,7 @@ void pic_get_zone_update(guint16 frame_id, guint16 pic_id, gint * x1, gint * y1,
 
 
 /* get old zone where the pic is displayed before change */
-void pic_get_zone_old(guint16 frame_id, guint16 pic_id, gint * x1, gint * y1, gint * x2, gint * y2) {
+void pic_get_zone_old(gint32 frame_id, gint32 pic_id, gint * x1, gint * y1, gint * x2, gint * y2) {
 
 	*x1 = frame[frame_id]->obj[pic_id]->x_old;
 	*y1 = frame[frame_id]->obj[pic_id]->y_old;
@@ -312,7 +311,7 @@ void pic_get_zone_old(guint16 frame_id, guint16 pic_id, gint * x1, gint * y1, gi
 
 
 /* get new zone where the pic is displayed after change */
-void pic_get_zone_new(guint16 frame_id, guint16 pic_id, gint * x1, gint * y1, gint * x2, gint * y2) {
+void pic_get_zone_new(gint32 frame_id, gint32 pic_id, gint * x1, gint * y1, gint * x2, gint * y2) {
 
 	*x1 = frame[frame_id]->obj[pic_id]->x;
 	*y1 = frame[frame_id]->obj[pic_id]->y;
@@ -324,15 +323,15 @@ void pic_get_zone_new(guint16 frame_id, guint16 pic_id, gint * x1, gint * y1, gi
 
 
 /* update bufout in selected zone */
-void eng_update_bufout(guint16 frame_id, guint16 x1, guint16 y1, guint16 x2, guint16 y2)  {
+void eng_update_bufout(gint32 frame_id, gint32 x1, gint32 y1, gint32 x2, gint32 y2)  {
 
-	guint32 i, j, k, l, tmp, pos, mask, alpha_mask, alpha_value, alpha;
-	guint   x1_pic, y1_pic, x2_pic, y2_pic;
-	guint16 x1_draw, y1_draw, x2_draw, y2_draw;
-	guint16 height_draw, width_draw;
-	guint32 ptr_memout, ptr_memobj;
-	guint16 pic_id;
-	guint16 obj_in_zone[MAX_PIC_PER_FRAME], nb_obj_in_zone; 
+	gint32 i, j, k, l, tmp, pos, mask, alpha_mask, alpha_value, alpha;
+	gint32 x1_pic, y1_pic, x2_pic, y2_pic;
+	gint32 x1_draw, y1_draw, x2_draw, y2_draw;
+	gint32 height_draw, width_draw;
+	gint32 ptr_memout, ptr_memobj;
+	gint32 pic_id;
+	gint32 obj_in_zone[MAX_PIC_PER_FRAME], nb_obj_in_zone; 
 
 	eng_set_bg_bufout(frame_id, x1, y1, x2, y2);
 
@@ -934,13 +933,13 @@ void eng_update_bufout(guint16 frame_id, guint16 x1, guint16 y1, guint16 x2, gui
 }
 
 
-void eng_set_bg_bufout(guint16 frame_id, guint16 x1, guint16 y1, guint16 x2, guint16 y2)  {
+void eng_set_bg_bufout(gint32 frame_id, gint32 x1, gint32 y1, gint32 x2, gint32 y2)  {
 
 	guint8 *ptr_memout = frame[frame_id]->bufout + (y1 * frame[frame_id]->width  + x1) * 3;
-	guint32 i, j;
-	guint32 height = y2 - y1 +1;
-	guint32 width = (x2 - x1 +1) * 3;
-	guint32 next = frame[frame_id]->width * 3;
+	gint32 i, j;
+	gint32 height = y2 - y1 +1;
+	gint32 width = (x2 - x1 +1) * 3;
+	gint32 next = frame[frame_id]->width * 3;
 
 	if(frame[frame_id]->gray_bgcolor)
 		for(i = 0 ; i < height ; i++, ptr_memout += next)
@@ -953,9 +952,9 @@ void eng_set_bg_bufout(guint16 frame_id, guint16 x1, guint16 y1, guint16 x2, gui
 }
 
 
-gboolean eng_zone_is_modified(guint16 frame_id, guint16 x1, guint16 y1, guint16 x2, guint16 y2)  {
+gboolean eng_zone_is_modified(gint32 frame_id, gint32 x1, gint32 y1, gint32 x2, gint32 y2)  {
 
-	guint32 i;
+	gint32 i;
 
 	for(i = 0 ; i < frame[frame_id]->nb_zone ; i++) {
 
@@ -972,9 +971,9 @@ gboolean eng_zone_is_modified(guint16 frame_id, guint16 x1, guint16 y1, guint16
 }
 
 
-gpointer eng_get_zone(guint16 frame_id, guint16 x1, guint16 y1, guint16 x2, guint16 y2)  {
+gpointer eng_get_zone(gint32 frame_id, gint32 x1, gint32 y1, gint32 x2, gint32 y2)  {
 
-	guint32 i, width, height, real_width, real_height, size;
+	gint32 i, width, height, real_width, real_height, size;
 
 	width = x2 - x1 +1;
 	height = y2 - y1 +1;
@@ -1006,9 +1005,9 @@ gpointer eng_get_zone(guint16 frame_id, guint16 x1, guint16 y1, guint16 x2, guin
 
 
 
-gpointer eng_get_next_zone(guint16 frame_id, guint16 * x, guint16 * y, guint16 * width, guint16 * height){
+gpointer eng_get_next_zone(gint32 frame_id, gint32 * x, gint32 * y, gint32 * width, gint32 * height){
 
-   guint32 i, x1, y1, x2 ,y2;
+	gint32 i, x1, y1, x2 ,y2;
 
 	for(i = 0 ; i < frame[frame_id]->nb_zone ; i++) {
 
