@@ -2,7 +2,7 @@
  *     gtkatlantic - the gtk+ monopd client, enjoy network monopoly games
  *
  *
- *  Copyright (C) 2002-2004 Rochet Sylvain
+ *  Copyright (C) 2002-2010 Rochet Sylvain
  *
  *  gtkatlantic is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -43,7 +43,7 @@ void engine_init()  {
 /* ---- engine init alpha table */
 void eng_init_alpha_table()  {
 
-	guint32 alpha, bright;
+	gint32 alpha, bright;
 
 #if ENG_DEBUG
 	fprintf(stdout, "Initializing alpha table...\n");
@@ -110,10 +110,10 @@ void engine_minimize_memory_usage()  {
  *    This function modify your input buffer, please make sure  *
  *    you don't need original mask                              *
  *                                                              */
-void engine_maskcompat(guint32 size, guint16 depth, guchar  * buff)  {
+void engine_maskcompat(gint32 size, gint32 depth, guint8  * buff)  {
 
-	guint32 nb_pixel, new_size;
-	guchar  * tmp;
+	gint32 nb_pixel, new_size;
+	guint8  * tmp;
 
 	if(!buff) return;
 	if(!engine->minimize_memory) return;
@@ -151,7 +151,7 @@ void engine_maskcompat(guint32 size, guint16 depth, guchar  * buff)  {
 /* ---- set engine->lastframe */
 void set_lastframe()  {
 
-	guint32 i, setval = 0;
+	gint32 i, setval = 0;
 
 	for(i = 1 ; i < MAX_FRAME ; i++)  {
 
@@ -163,9 +163,9 @@ void set_lastframe()  {
 
 
 /* ---- create a new frame */
-guint16 frame_create()  {
+gint32 frame_create()  {
 
-	guint32 i;
+	gint32 i;
  
 	/* search the first free frame  */
 	for(i = 1 ; i < MAX_FRAME ; i++)  {
@@ -196,9 +196,9 @@ guint16 frame_create()  {
  *
  *    close also all pics
  */
-void frame_destroy(guint16 frame_id)  {
+void frame_destroy(gint32 frame_id)  {
 
-	guint32 i;
+	gint32 i;
 
 	if(!engine->active_frame[frame_id]) return;
 
@@ -220,7 +220,7 @@ void frame_destroy(guint16 frame_id)  {
 /* ---- destroy all frames */
 void frame_destroy_all()  {
 
-	guint32 i;
+	gint32 i;
 
 	for(i = 1 ; i <= engine->lastframe ; i++) {
 
@@ -230,9 +230,9 @@ void frame_destroy_all()  {
 
 
 /* ---- set to 0 all elements in struct */
-void frame_reset(guint16 frame_id)  {
+void frame_reset(gint32 frame_id)  {
 
-	guint32 i;
+	gint32 i;
 
 	if(!engine->active_frame[frame_id]) return;
 
@@ -272,7 +272,7 @@ void frame_reset(guint16 frame_id)  {
 
 
 /* ---- compute yes this frame (for eng_create_frame_all() ) */
-void frame_set_compute(guint16 frame_id) {
+void frame_set_compute(gint32 frame_id) {
 
 	if(!engine->active_frame[frame_id]) return;
 
@@ -281,7 +281,7 @@ void frame_set_compute(guint16 frame_id) {
 
 
 /* ---- compute no this frame (for eng_create_frame_all() ) */
-void frame_unset_compute(guint16 frame_id)  {
+void frame_unset_compute(gint32 frame_id)  {
 
 	if(!engine->active_frame[frame_id]) return;
 
@@ -302,9 +302,9 @@ void frame_unset_compute(guint16 frame_id)  {
  *                                                    *
  *  This is not dependant with minimizing memory mode *
  *                                                    */
-void frame_clean(guint16 frame_id)  {
+void frame_clean(gint32 frame_id)  {
 
-	guint32 i;
+	gint32 i;
 
 	if(!engine->active_frame[frame_id]) return;
 
@@ -337,7 +337,7 @@ void frame_clean(guint16 frame_id)  {
 
 
 /* ---- set HEIGHT of a frame */
-void frame_set_height(guint16 frame_id, guint16 height)  {
+void frame_set_height(gint32 frame_id, gint32 height)  {
 
 	if(!engine->active_frame[frame_id]) return;
 
@@ -346,7 +346,7 @@ void frame_set_height(guint16 frame_id, guint16 height)  {
 
 
 /* ---- set WIDTH of a frame */
-void frame_set_width(guint16 frame_id, guint16 width)  {
+void frame_set_width(gint32 frame_id, gint32 width)  {
 
 	if(!engine->active_frame[frame_id]) return;
 
@@ -355,7 +355,7 @@ void frame_set_width(guint16 frame_id, guint16 width)  {
 
 
 /* ---- set BGCOLOR of a frame */
-void frame_set_bgcolor(guint16 frame_id, guint32 bgcolor)  {
+void frame_set_bgcolor(gint32 frame_id, gint32 bgcolor)  {
 
 	if(!engine->active_frame[frame_id]) return;
 
@@ -371,9 +371,9 @@ void frame_set_bgcolor(guint16 frame_id, guint32 bgcolor)  {
 
 
 /* ---- set lastpic of a frame */
-void frame_set_lastpic(guint16 frame_id)  {
+void frame_set_lastpic(gint32 frame_id)  {
 
-	guint32 i, setval = 0;
+	gint32 i, setval = 0;
 
 	if(!engine->active_frame[frame_id]) return;
 
@@ -387,9 +387,9 @@ void frame_set_lastpic(guint16 frame_id)  {
 
 
 /* ---- set lastground of a frame */
-void frame_set_lastground(guint16 frame_id)  {
+void frame_set_lastground(gint32 frame_id)  {
 
-	guint32 i, setval = 0;
+	gint32 i, setval = 0;
 
 	if(!engine->active_frame[frame_id]) return;
 
@@ -403,7 +403,7 @@ void frame_set_lastground(guint16 frame_id)  {
 
 
 /* ---- return nb_bytes to allocate for a frame */
-guint32 frame_size_frame(guint16 frame_id)  {
+gint32 frame_size_frame(gint32 frame_id)  {
 
 	if(!engine->active_frame[frame_id]) return(FALSE);
 
@@ -412,7 +412,7 @@ guint32 frame_size_frame(guint16 frame_id)  {
 
 
 /* ---- put in terminal all arguments of a frame */
-void frame_showarg(guint16 frame_id)  {
+void frame_showarg(gint32 frame_id)  {
 
 	if(!engine->active_frame[frame_id]) return;
 
@@ -441,7 +441,7 @@ void frame_showarg(guint16 frame_id)  {
 
 
 /* ---- test engine arguments */
-gboolean frame_test(guint16 frame_id)  {
+gboolean frame_test(gint32 frame_id)  {
 
 	if(!engine->active_frame[frame_id]) return(FALSE);
 
@@ -456,9 +456,9 @@ gboolean frame_test(guint16 frame_id)  {
 
 
 /* ---- create a new pic */
-guint16 pic_create(guint16 frame_id)  {
+gint32 pic_create(gint32 frame_id)  {
 
-	guint32 i;
+	gint32 i;
  
 	if(!engine->active_frame[frame_id]) {
 
@@ -493,7 +493,7 @@ guint16 pic_create(guint16 frame_id)  {
 
 
 /* ---- destroy pic */
-void pic_destroy(guint16 frame_id, guint16 pic_id)  {
+void pic_destroy(gint32 frame_id, gint32 pic_id)  {
 
 	if(!engine->active_frame[frame_id]) return;
 	if(!frame[frame_id]->active_pic[pic_id]) return;
@@ -514,7 +514,7 @@ void pic_destroy(guint16 frame_id, guint16 pic_id)  {
 
 
 /* ---- set to 0 all elements in struct */
-void pic_reset(guint16 frame_id, guint16 pic_id)  {
+void pic_reset(gint32 frame_id, gint32 pic_id)  {
 
 	if(!engine->active_frame[frame_id]) return;
 	if(!frame[frame_id]->active_pic[pic_id]) return;
@@ -553,7 +553,7 @@ void pic_reset(guint16 frame_id, guint16 pic_id)  {
 
 
 /* ---- show this pic */
-void pic_show(guint16 frame_id, guint16 pic_id) {
+void pic_show(gint32 frame_id, gint32 pic_id) {
 
 	if(!engine->active_frame[frame_id]) return;
 	if(!frame[frame_id]->active_pic[pic_id]) return;
@@ -567,7 +567,7 @@ void pic_show(guint16 frame_id, guint16 pic_id) {
 
 
 /* ---- unshow this pic */
-void pic_unshow(guint16 frame_id, guint16 pic_id) {
+void pic_unshow(gint32 frame_id, gint32 pic_id) {
 
 	if(!engine->active_frame[frame_id]) return;
 	if(!frame[frame_id]->active_pic[pic_id]) return;
@@ -581,7 +581,7 @@ void pic_unshow(guint16 frame_id, guint16 pic_id) {
 
 
 /* ---- mask yes this pic */
-void pic_is_mask(guint16 frame_id, guint16 pic_id) {
+void pic_is_mask(gint32 frame_id, gint32 pic_id) {
 
 	if(!engine->active_frame[frame_id]) return;
 	if(!frame[frame_id]->active_pic[pic_id]) return;
@@ -596,7 +596,7 @@ void pic_is_mask(guint16 frame_id, guint16 pic_id) {
 
 
 /* ---- mask no this pic */
-void pic_isnot_mask(guint16 frame_id, guint16 pic_id) {
+void pic_isnot_mask(gint32 frame_id, gint32 pic_id) {
 
 	if(!engine->active_frame[frame_id]) return;
 	if(!frame[frame_id]->active_pic[pic_id]) return;
@@ -610,7 +610,7 @@ void pic_isnot_mask(guint16 frame_id, guint16 pic_id) {
 
 
 /* ---- alpha yes this pic */
-void pic_is_alphamask(guint16 frame_id, guint16 pic_id) {
+void pic_is_alphamask(gint32 frame_id, gint32 pic_id) {
 
 	if(!engine->active_frame[frame_id]) return;
 	if(!frame[frame_id]->active_pic[pic_id]) return;
@@ -625,7 +625,7 @@ void pic_is_alphamask(guint16 frame_id, guint16 pic_id) {
 
 
 /* ---- alpha no this pic */
-void pic_isnot_alphamask(guint16 frame_id, guint16 pic_id) {
+void pic_isnot_alphamask(gint32 frame_id, gint32 pic_id) {
 
 	if(!engine->active_frame[frame_id]) return;
 	if(!frame[frame_id]->active_pic[pic_id]) return;
@@ -639,7 +639,7 @@ void pic_isnot_alphamask(guint16 frame_id, guint16 pic_id) {
 
 
 /* ---- set X pos of pic */
-void pic_set_x(guint16 frame_id, guint16 pic_id, guint16 x)  {
+void pic_set_x(gint32 frame_id, gint32 pic_id, gint32 x)  {
 
 	if(!engine->active_frame[frame_id]) return;
 	if(!frame[frame_id]->active_pic[pic_id]) return;
@@ -653,7 +653,7 @@ void pic_set_x(guint16 frame_id, guint16 pic_id, guint16 x)  {
 
 
 /* ---- set Y pos of pic */
-void pic_set_y(guint16 frame_id, guint16 pic_id, guint16 y)  {
+void pic_set_y(gint32 frame_id, gint32 pic_id, gint32 y)  {
 
 	if(!engine->active_frame[frame_id]) return;
 	if(!frame[frame_id]->active_pic[pic_id]) return;
@@ -667,7 +667,7 @@ void pic_set_y(guint16 frame_id, guint16 pic_id, guint16 y)  {
 
 
 /* ---- set Z pos of pic */
-void pic_set_z(guint16 frame_id, guint16 pic_id, guint16 z)  {
+void pic_set_z(gint32 frame_id, gint32 pic_id, gint32 z)  {
 
 	if(!engine->active_frame[frame_id]) return;
 	if(!frame[frame_id]->active_pic[pic_id]) return;
@@ -682,7 +682,7 @@ void pic_set_z(guint16 frame_id, guint16 pic_id, guint16 z)  {
 
 
 /* ---- set HEIGHT of pic */
-void pic_set_height(guint16 frame_id, guint16 pic_id, guint16 height)  {
+void pic_set_height(gint32 frame_id, gint32 pic_id, gint32 height)  {
 
 	if(!engine->active_frame[frame_id]) return;
 	if(!frame[frame_id]->active_pic[pic_id]) return;
@@ -696,7 +696,7 @@ void pic_set_height(guint16 frame_id, guint16 pic_id, guint16 height)  {
 
 
 /* ---- set WIDTH of pic */
-void pic_set_width(guint16 frame_id, guint16 pic_id, guint16 width)  {
+void pic_set_width(gint32 frame_id, gint32 pic_id, gint32 width)  {
 
 	if(!engine->active_frame[frame_id]) return;
 	if(!frame[frame_id]->active_pic[pic_id]) return;
@@ -710,7 +710,7 @@ void pic_set_width(guint16 frame_id, guint16 pic_id, guint16 width)  {
 
 
 /* ---- set DEPTH of pic (only for mask) */
-void pic_set_depth(guint16 frame_id, guint16 pic_id, guint16 depth)  {
+void pic_set_depth(gint32 frame_id, gint32 pic_id, gint32 depth)  {
 
 	if(!engine->active_frame[frame_id]) return;
 	if(!frame[frame_id]->active_pic[pic_id]) return;
@@ -720,7 +720,7 @@ void pic_set_depth(guint16 frame_id, guint16 pic_id, guint16 depth)  {
 
 
 /* ---- set TRANSP color of pic */
-void pic_set_transp(guint16 frame_id, guint16 pic_id, guint32 transp)  {
+void pic_set_transp(gint32 frame_id, gint32 pic_id, gint32 transp)  {
 
 	if(!engine->active_frame[frame_id]) return;
 	if(!frame[frame_id]->active_pic[pic_id]) return;
@@ -735,7 +735,7 @@ void pic_set_transp(guint16 frame_id, guint16 pic_id, guint32 transp)  {
 
 
 /* ---- UNset TRANSP color of pic */
-void pic_unset_transp(guint16 frame_id, guint16 pic_id)  {
+void pic_unset_transp(gint32 frame_id, gint32 pic_id)  {
 
 	if(!engine->active_frame[frame_id]) return;
 	if(!frame[frame_id]->active_pic[pic_id]) return;
@@ -750,7 +750,7 @@ void pic_unset_transp(guint16 frame_id, guint16 pic_id)  {
 
 
 /* ---- set ALPHA value */
-void pic_set_alpha(guint16 frame_id, guint16 pic_id, guint8 alpha)  {
+void pic_set_alpha(gint32 frame_id, gint32 pic_id, guint8 alpha)  {
 
 	if(!engine->active_frame[frame_id]) return;
 	if(!frame[frame_id]->active_pic[pic_id]) return;
@@ -772,7 +772,7 @@ void pic_set_alpha(guint16 frame_id, guint16 pic_id, guint8 alpha)  {
 
 
 /* ---- UNset ALPHA value */
-void pic_unset_alpha(guint16 frame_id, guint16 pic_id)  {
+void pic_unset_alpha(gint32 frame_id, gint32 pic_id)  {
 
 	if(!engine->active_frame[frame_id]) return;
 	if(!frame[frame_id]->active_pic[pic_id]) return;
@@ -787,7 +787,7 @@ void pic_unset_alpha(guint16 frame_id, guint16 pic_id)  {
 
 
 /* ---- set MASK of pic */
-void pic_set_mask(guint16 frame_id, guint16 pic_id, guint16 mask_id)  {
+void pic_set_mask(gint32 frame_id, gint32 pic_id, gint32 mask_id)  {
 
 	if(!engine->active_frame[frame_id]) return;
 	if(!frame[frame_id]->active_pic[pic_id]) return;
@@ -802,7 +802,7 @@ void pic_set_mask(guint16 frame_id, guint16 pic_id, guint16 mask_id)  {
 
 
 /* ---- UNset MASK of pic */
-void pic_unset_mask(guint16 frame_id, guint16 pic_id)  {
+void pic_unset_mask(gint32 frame_id, gint32 pic_id)  {
 
 	if(!engine->active_frame[frame_id]) return;
 	if(!frame[frame_id]->active_pic[pic_id]) return;
@@ -817,7 +817,7 @@ void pic_unset_mask(guint16 frame_id, guint16 pic_id)  {
 
 
 /* ---- set ALPHAMASK of pic */
-void pic_set_alphamask(guint16 frame_id, guint16 pic_id, guint16 alpha_id)  {
+void pic_set_alphamask(gint32 frame_id, gint32 pic_id, gint32 alpha_id)  {
 
 	if(!engine->active_frame[frame_id]) return;
 	if(!frame[frame_id]->active_pic[pic_id]) return;
@@ -834,7 +834,7 @@ void pic_set_alphamask(guint16 frame_id, guint16 pic_id, guint16 alpha_id)  {
 
 
 /* ---- UNset ALPHAMASK of pic */
-void pic_unset_alphamask(guint16 frame_id, guint16 pic_id)  {
+void pic_unset_alphamask(gint32 frame_id, gint32 pic_id)  {
 
 	if(!engine->active_frame[frame_id]) return;
 	if(!frame[frame_id]->active_pic[pic_id]) return;
@@ -849,7 +849,7 @@ void pic_unset_alphamask(guint16 frame_id, guint16 pic_id)  {
 
 
 /* ---- set BGCOLOR value */
-void pic_set_bgcolor(guint16 frame_id, guint16 pic_id, guint32 bgcolor)  {
+void pic_set_bgcolor(gint32 frame_id, gint32 pic_id, gint32 bgcolor)  {
 
 	guint8 rgb[3];
 
@@ -870,7 +870,7 @@ void pic_set_bgcolor(guint16 frame_id, guint16 pic_id, guint32 bgcolor)  {
 
 
 /* ---- UNset BGCOLOR value */
-void pic_unset_bgcolor(guint16 frame_id, guint16 pic_id)  {
+void pic_unset_bgcolor(gint32 frame_id, gint32 pic_id)  {
 
 	if(!engine->active_frame[frame_id]) return;
 	if(!frame[frame_id]->active_pic[pic_id]) return;
@@ -888,7 +888,7 @@ void pic_unset_bgcolor(guint16 frame_id, guint16 pic_id)  {
 
 /* ---- set/fill BUFFER of pic                * 
  *    call pic_fill_buff() or pic_set_buff()  */
-void pic_buff(guint16 frame_id, guint16 pic_id, guchar  * buff)  {
+void pic_buff(gint32 frame_id, gint32 pic_id, guint8  * buff)  {
 
 	if(!engine->active_frame[frame_id]) return;
 	if(!frame[frame_id]->active_pic[pic_id]) return;
@@ -902,9 +902,9 @@ void pic_buff(guint16 frame_id, guint16 pic_id, guchar  * buff)  {
 
 /* ---- fill BUFFER of pic             *
  *    copy image buffer under engine   */
-void pic_fill_buff(guint16 frame_id, guint16 pic_id, guchar  * buff)  {
+void pic_fill_buff(gint32 frame_id, gint32 pic_id, guint8  * buff)  {
 
-	guint32 size = 0, sizechg = 0, chg = 0, nb_pixel;
+	gint32 size = 0, sizechg = 0, chg = 0, nb_pixel;
 
 	if(!engine->active_frame[frame_id]) return;
 	if(!frame[frame_id]->active_pic[pic_id]) return;
@@ -980,7 +980,7 @@ void pic_fill_buff(guint16 frame_id, guint16 pic_id, guchar  * buff)  {
 
 /* ---- set BUFFER of pic        *
  *     don't copy image buffer   */
-void pic_set_buff(guint16 frame_id, guint16 pic_id, guchar  * buff)  {
+void pic_set_buff(gint32 frame_id, gint32 pic_id, guint8  * buff)  {
 
 	if(!engine->active_frame[frame_id]) return;
 	if(!frame[frame_id]->active_pic[pic_id]) return;
@@ -999,7 +999,7 @@ void pic_set_buff(guint16 frame_id, guint16 pic_id, guchar  * buff)  {
 
 
 /* ---- put in terminal all arguments of a pic */
-void pic_showarg(guint16 frame_id, guint16 pic_id)  {
+void pic_showarg(gint32 frame_id, gint32 pic_id)  {
 
 	if(!engine->active_frame[frame_id]) return;
 	if(!frame[frame_id]->active_pic[pic_id]) return;
@@ -1046,9 +1046,9 @@ void pic_showarg(guint16 frame_id, guint16 pic_id)  {
 
 
 /* ---- test if depth of mask pic_id is good */
-gboolean pic_mask_test_depth(guint16 frame_id, guint16 pic_id)  {
+gboolean pic_mask_test_depth(gint32 frame_id, gint32 pic_id)  {
 
-	guint16 depth = 0;
+	gint32 depth = 0;
 
 	if(!engine->active_frame[frame_id]) return(FALSE);
 	if(!frame[frame_id]->active_pic[pic_id]) return(FALSE);
@@ -1062,10 +1062,10 @@ gboolean pic_mask_test_depth(guint16 frame_id, guint16 pic_id)  {
 
 
 /* ---- test if pic was good */
-gboolean pic_test(guint16 frame_id, guint16 pic_id)  {
+gboolean pic_test(gint32 frame_id, gint32 pic_id)  {
 
-	guint32 size;
-	guint32 mask, alphamask;
+	gint32 size;
+	gint32 mask, alphamask;
 
 	/* --> common */
 	if(!engine->active_frame[frame_id]) return(FALSE);
@@ -1193,7 +1193,7 @@ gboolean pic_test(guint16 frame_id, guint16 pic_id)  {
 
 
 /* ---- return max color value */
-guint32 max_col_val(guint16 depth)  {
+gint32 max_col_val(gint32 depth)  {
 
 	switch(depth)  {
 
@@ -1211,16 +1211,16 @@ guint32 max_col_val(guint16 depth)  {
 /* ---- return max color value
         special for 24 bits mode, because this function
         is often call, just for faster      */
-guint32 max_col_val_24()  {
+gint32 max_col_val_24()  {
 
 	return(0xFFFFFF);
 }
 
 
 /* ---- return nb of byte to allocate for buf */
-guint32 calc_buf_size(guint32 width, guint32 height, guint16 depth)  {
+gint32 calc_buf_size(gint32 width, gint32 height, gint32 depth)  {
 
-	guint32 tmp;
+	gint32 tmp;
 
 	if(height <= 0  ||  width <= 0) return(FALSE);
 
@@ -1245,7 +1245,7 @@ guint32 calc_buf_size(guint32 width, guint32 height, guint16 depth)  {
 /* ---- return nb of byte to allocate for buf
         special for 24 bits mode, because this function
         is often call, just for faster      */
-guint32 calc_buf_size_24(guint32 width, guint32 height)  {
+gint32 calc_buf_size_24(gint32 width, gint32 height)  {
 
 	if(height <= 0  ||  width <= 0) return(FALSE);
 
