@@ -2,7 +2,7 @@
  *     gtkatlantic - the gtk+ monopd client, enjoy network monopoly games
  *
  *
- *  Copyright (C) 2002-2004 Rochet Sylvain
+ *  Copyright (C) 2002-2010 Rochet Sylvain
  *
  *  gtkatlantic is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -46,7 +46,7 @@
  * return TRUE if exist/created, return FALSE if cannot be created */
 gboolean create_home_directory()  {
 
-	guchar *path;
+	gchar *path;
 	struct stat s;
 
 	path = g_strconcat( getenv("HOME"), "/", ".", PACKAGE, "/", NULL);
@@ -81,7 +81,7 @@ gboolean create_home_directory()  {
 /* read config files */
 void read_config_files()   {
 
-	guchar *filename;
+	gchar *filename;
 	struct stat s;
 
 	/* read default config file */
@@ -104,9 +104,9 @@ void read_config_files()   {
 
 /* return a valid slot for a connection     *
  *   else return FALSE                      */
-gboolean connect_get_valid_id(guint16 *idconnect)  {
+gboolean connect_get_valid_id(gint32 *idconnect)  {
 
-	guint16 i;
+	gint32 i;
 
 	for(i = 1; i < MAX_CONNECTION; i++)
 		if(!connection_is_open[i]) {
@@ -120,9 +120,9 @@ gboolean connect_get_valid_id(guint16 *idconnect)  {
 
 
 /* this function made a new connection for metaserver (list & games) */
-void create_connection_metaserver(guint32 gametype)  {
+void create_connection_metaserver(gint32 gametype)  {
 
-	guint16 connectid;
+	gint32 connectid;
 	gchar *sendstr;
 
 	if(! client_connect(&connectid, config->metaserver_host, config->metaserver_port) ) return;
@@ -150,9 +150,9 @@ void create_connection_metaserver(guint32 gametype)  {
 
 
 /* this function made a new connection for get games only */
-void create_connection_get_games(guchar *host, guint32 port)  {
+void create_connection_get_games(gchar *host, gint32 port)  {
 
-	guint16 connectid;
+	gint32 connectid;
 	gchar *sendstr;
 
 	if(! client_connect(&connectid, host, port) ) return;
@@ -165,13 +165,13 @@ void create_connection_get_games(guchar *host, guint32 port)  {
 
 
 /* insert test in Message Box */
-void text_insert_message(gchar* text, guint32 length)  {
+void text_insert_message(gchar* text, gint32 length)  {
 
 	GtkTextBuffer *textbuff;
 	GtkTextIter textiter;
 	GtkTextMark *textmark;
 
-	guint32 i, len;
+//	gint32 i, len;
 
 	if(global->phase < PHASE_GETGAMES) return;
 
@@ -189,16 +189,16 @@ void text_insert_message(gchar* text, guint32 length)  {
 
 //	while(global->message_nb_lines > config->message_max_lines) {
 
-		/* if unlimited */
+		// if unlimited
 /*		if(config->message_max_lines <= 0)  break;
 
 		len = gtk_text_get_length( GTK_TEXT(global->Message) );
 
 		for(i = 0 ;  GTK_TEXT_INDEX( GTK_TEXT(global->Message), i) != '\n' ; i++)  {
 
-			if(i >= len)  { /* argl... no CR founded */
+			if(i >= len)  { // argl... no CR found
 
-/*				gtk_text_set_point( GTK_TEXT(global->Message), 0);
+				gtk_text_set_point( GTK_TEXT(global->Message), 0);
 				gtk_text_forward_delete( GTK_TEXT(global->Message), len);
 				global->message_nb_lines = 0;
 				break;
@@ -225,13 +225,13 @@ void text_insert_message(gchar* text, guint32 length)  {
 
 
 /* insert test in Chat Box */
-void text_insert_chat(gchar* text, guint32 length)
+void text_insert_chat(gchar* text, gint32 length)
 {
 	GtkTextBuffer *textbuff;
 	GtkTextIter textiter;
 	GtkTextMark *textmark;
 
-	guint32 i, len;
+//	gint32 i, len;
 
 	if(global->phase < PHASE_GAMECREATE)
 		return;
@@ -250,16 +250,16 @@ void text_insert_chat(gchar* text, guint32 length)
 
 /*	while(game->chat_nb_lines > config->chat_max_lines) {
 
-		/* if unlimited */
-/*		if(config->chat_max_lines <= 0)  break;
+		// if unlimited
+		if(config->chat_max_lines <= 0)  break;
 
 		len = gtk_text_get_length( GTK_TEXT(game->Chat) );
 
 		for(i = 0 ;  GTK_TEXT_INDEX( GTK_TEXT(game->Chat), i) != '\n' ; i++)  {
 
-			if(i >= len)  { /* argl... no CR founded */
+			if(i >= len)  { // argl... no CR found
 
-/*				gtk_text_set_point( GTK_TEXT(game->Chat), 0);
+				gtk_text_set_point( GTK_TEXT(game->Chat), 0);
 				gtk_text_forward_delete( GTK_TEXT(game->Chat), len);
 				game->chat_nb_lines = 0;
 				break;
@@ -296,7 +296,7 @@ void game_alloc()  {
 /* free entirely a game, return to get games page */
 void game_free()  {
 
-	guint32 i;
+	gint32 i;
 
 	client_disconnect(game->connectid);
 
@@ -311,13 +311,7 @@ void game_free()  {
 	for(i = 0 ; i < MAX_PLAYERS ; i++)  {
 
 		if(! global->player[i].playerid) continue;
-
-		if(global->player[i].name) g_free(global->player[i].name);
-		if(global->player[i].host) g_free(global->player[i].host);
-		if(global->player[i].image) g_free(global->player[i].image);
-
-		frame_destroy( global->player[i].playerlist_token_frame );
-		frame_destroy( global->player[i].playerlist_cards_frame );
+		game_delete_player(i);
 	}
 
 	for(i = 0 ; i < data->number_estates ; i++)  {
@@ -351,13 +345,13 @@ void game_free()  {
 
 
 /* return a valid game id */
-gboolean game_get_valid_player_slot(guint8 *playerslot)  {
+gboolean game_get_valid_player_slot(gint32 *playerslot)  {
 
-	guint32 i;
+	gint32 i;
 
 	for(i = 0; i < MAX_PLAYERS; i++)
 		if(!global->player[i].playerid) {
-
+	
 			*playerslot = i;
 			return TRUE;
 		}
@@ -367,9 +361,9 @@ gboolean game_get_valid_player_slot(guint8 *playerslot)  {
 
 
 /* return the player slot of playerid */
-gint8 get_player_slot_with_playerid(guint32 playerid)  {
+gint32 get_player_slot_with_playerid(gint32 playerid)  {
 
-	guint32 i;
+	gint32 i;
 
 	for(i = 0 ; i < MAX_PLAYERS ; i++)  {
 
@@ -384,9 +378,9 @@ gint8 get_player_slot_with_playerid(guint32 playerid)  {
 }
 
 
-gint8 get_playerlistcard_id_with_estate(guint32 estate)  {
+gint32 get_playerlistcard_id_with_estate(gint32 estate)  {
 
-	guint32 i;
+	gint32 i;
 
 	for(i = 0 ; i < data->number_playerlist_card ; i++)  {
 
@@ -402,9 +396,9 @@ gint8 get_playerlistcard_id_with_estate(guint32 estate)  {
 
 
 /* return a valid command slotid */
-gboolean game_get_valid_command_slot(guint8 *commandslot)  {
+gboolean game_get_valid_command_slot(gint32 *commandslot)  {
 
-	guint8 i;
+	gint32 i;
 
 	for(i = 0; i < MAX_COMMANDS ; i++)
 		if(!game->command[i].open) {
@@ -419,9 +413,9 @@ gboolean game_get_valid_command_slot(guint8 *commandslot)  {
 
 /* return commandslot if button command is displayed
    return <0 if button not is not displayed           */
-gint8 get_command_button_slot_with_command(guchar *command) {
+gint32 get_command_button_slot_with_command(gchar *command) {
 
-	guint32 i;
+	gint32 i;
 
 	for(i = 0 ; i < MAX_COMMANDS ; i ++)  {
 
@@ -437,10 +431,10 @@ gint8 get_command_button_slot_with_command(guchar *command) {
 
 
 /* send specific chat message, like version */
-void parse_specific_chat_message(guchar *message)   {
+void parse_specific_chat_message(gchar *message)   {
 
-	guchar *msg, *sendstr;
-	guint32 pslot;
+	gchar *msg, *sendstr;
+	gint32 pslot;
 
 	struct timeval tv;
 	time_t t_now;
@@ -509,11 +503,10 @@ void parse_specific_chat_message(guchar *message)   {
 
 
 /* parse specific send message */
-void parse_specific_send_message(guchar *message)   {
+void parse_specific_send_message(gchar *message)   {
 
-	guchar *msg, *tmp;
-	guint32 i;
-	gint32 playerid, pslot;
+	gchar *msg, *tmp;
+	gint32 i, playerid, pslot;
 
 	struct timeval tv;
 	struct tm *local_tm;
@@ -631,7 +624,7 @@ void parse_specific_send_message(guchar *message)   {
 /* sort playerlist by playerid (ascending) */
 void game_sort_playerlist_by_playerid()  {
 
-	guint32 i, j;
+	gint32 i, j;
 	_player playertmp;
 
 	for(i = 0 ; i < MAX_PLAYERS ; i++)  {
@@ -654,9 +647,9 @@ void game_sort_playerlist_by_playerid()  {
 
 
 /* write cookie on disk */
-void game_write_cookie(guchar *cookie)  {
+void game_write_cookie(gchar *cookie)  {
 
-	guchar *filename, *errormsg;
+	gchar *filename, *errormsg;
 	FILE *file;
 
 	filename = g_strconcat(global->path_home, "cookie", NULL);
@@ -680,9 +673,9 @@ void game_write_cookie(guchar *cookie)  {
 
 
 /* return a valid card slotid */
-gboolean game_get_valid_card_slot(guint8 *cardslot)  {
+gboolean game_get_valid_card_slot(gint32 *cardslot)  {
 
-	guint8 i;
+	gint32 i;
 
 	for(i = 0; i < MAX_CARDS ; i++)
 		if(!game->card[i].owner) {
@@ -696,9 +689,9 @@ gboolean game_get_valid_card_slot(guint8 *cardslot)  {
 
 
 /* return the card slot by cardid */
-gint8 get_card_slot_with_cardid(guint32 cardid)  {
+gint32 get_card_slot_with_cardid(gint32 cardid)  {
 
-	guint32 i;
+	gint32 i;
 
 	for(i = 0 ; i < MAX_CARDS ; i++)  {
 
@@ -714,9 +707,9 @@ gint8 get_card_slot_with_cardid(guint32 cardid)  {
 
 
 /* return player identifier by name of this player */
-gint32 get_playerid_by_playername(guchar *name)  {
+gint32 get_playerid_by_playername(gchar *name)  {
 
-	guint32 i;
+	gint32 i;
 
 	if(!name) return(-1);
 	if(strlen(name) <= 0) return(-1);
@@ -724,7 +717,8 @@ gint32 get_playerid_by_playername(guchar *name)  {
 	for(i = 0 ; i < MAX_PLAYERS ; i++)  {
 
 		if(! global->player[i].playerid)  continue;
-
+		if(!global->player[i].name) continue;
+		
 		if(! strcmp(global->player[i].name, name) )  {
 
 			return( global->player[i].playerid );
@@ -736,10 +730,22 @@ gint32 get_playerid_by_playername(guchar *name)  {
 }
 
 
-/* return a valid trade slotid */
-gboolean game_get_valid_trade_slot(guint32 *tradeslot)  {
+gint32 game_nb_players() {
+	gint32 i, c = 0;
 
-	guint32 i;
+	for(i = 0 ; i < MAX_PLAYERS ; i++)  {
+
+		if(!global->player[i].playerid)  continue;
+		if(global->player[i].game != game->gameid)  continue;
+		c++;
+	}
+	return c;
+}
+
+/* return a valid trade slotid */
+gboolean game_get_valid_trade_slot(gint32 *tradeslot)  {
+
+	gint32 i;
 
 	for(i = 0; i < MAX_TRADES ; i++)
 		if(! game->trade[i].open) {
@@ -753,9 +759,9 @@ gboolean game_get_valid_trade_slot(guint32 *tradeslot)  {
 
 
 /* return trade slot by tradeid */
-gint32 get_trade_slot_with_tradeid(guint32 tradeid)  {
+gint32 get_trade_slot_with_tradeid(gint32 tradeid)  {
 
-	guint32 i;
+	gint32 i;
 
 	for(i = 0 ; i < MAX_TRADES ; i++)  {
 
@@ -774,9 +780,9 @@ gint32 get_trade_slot_with_tradeid(guint32 tradeid)  {
 
 
 /* return estate identifier by name of this estate */
-gint32 get_estateid_by_estatename(guchar *name)  {
+gint32 get_estateid_by_estatename(gchar *name)  {
 
-	guint32 i;
+	gint32 i;
 
 	for(i = 0 ; i < data->number_estates ; i++)  {
 
@@ -794,8 +800,7 @@ gint32 get_estateid_by_estatename(guchar *name)  {
 /* build player list in game config phase */
 void game_buildplayerlist()   {
 
-	guint32 i;
-	gint32 row;
+	gint32 i, row;
 	gchar *txt[10];
 
 	game_sort_playerlist_by_playerid();
@@ -825,10 +830,9 @@ void game_buildplayerlist()   {
 /* return assets of a player,
  *   assets is: money + sale price of houses + unmortgaged value of estates
  */
-gint32 game_get_assets_player(guint32 playerid)  {
+gint32 game_get_assets_player(gint32 playerid)  {
 
-	guint32 i;
-	gint32 pslot, assets;
+	gint32 i, pslot, assets;
 
 	pslot = get_player_slot_with_playerid( playerid );
 	if(pslot < 0)  return 0;
@@ -1004,9 +1008,9 @@ void game_update_tokens()  {
 
 
 /* start token movement */
-void game_start_move_token(guint32 playerid)  {
+void game_start_move_token(gint32 playerid)  {
 
-	guchar *sendstr;
+	gchar *sendstr;
 	gint32 pslot;
 
 	pslot = get_player_slot_with_playerid(playerid);
@@ -1029,8 +1033,8 @@ void game_start_move_token(guint32 playerid)  {
 /* animate move token */
 gboolean game_move_tokens()  {
 
-	guint32 i;
-	guchar *sendstr;
+	gint32 i;
+	gchar *sendstr;
 	gboolean update = 0;
 
 	for(i = 0 ; i < MAX_PLAYERS ; i++)  {
@@ -1056,12 +1060,15 @@ gboolean game_move_tokens()  {
 }
 
 
-void game_delete_player(guint32 id)  {
+void game_delete_player(gint32 id)  {
 
 	/* delete a player */
+	frame_destroy( global->player[id].playerlist_token_frame );
+	frame_destroy( global->player[id].playerlist_cards_frame );
+	
 	if(global->player[id].name) g_free(global->player[id].name);
 	if(global->player[id].host) g_free(global->player[id].host);
 	if(global->player[id].image) g_free(global->player[id].image);
+	
 	memset(&global->player[id], 0, sizeof(_player) );
-	game->nb_players--;
 }
