@@ -2,7 +2,7 @@
  *     gtkatlantic - the gtk+ monopd client, enjoy network monopoly games
  *
  *
- *  Copyright (C) 2002-2004 Rochet Sylvain
+ *  Copyright (C) 2002-2010 Rochet Sylvain
  *
  *  gtkatlantic is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -59,9 +59,9 @@ typedef struct {
 
 	guint32  playerid;
 	gint32   game;
-	guchar   *image;
-	guchar   *name;
-	guchar   *host;
+	gchar   *image;
+	gchar   *name;
+	gchar   *host;
 	gboolean master;
 	gint32   money;
 	guint16  location;
@@ -107,7 +107,7 @@ typedef struct {
 /* -- estate data */
 typedef struct {
 
-	guchar   *name;
+	gchar   *name;
 	guint8   color[3];   // R, G, B
 	guint8   bgcolor[3]; // R, G, B
 	gint32   owner;
@@ -143,7 +143,7 @@ typedef struct {
 /* -- group data */
 typedef struct {
 
-	guchar *name;
+	gchar *name;
 
 } _group;
 
@@ -200,7 +200,7 @@ typedef struct {
 	GtkWidget *gdkrgb;
 	gboolean   redraw;
 
-	guchar *command;
+	gchar *command;
 
 } _command;
 
@@ -226,7 +226,6 @@ typedef struct {
 	guint16 connectid;
 	time_t start_time;
 	guint16 board_frame;
-	guint8 nb_players;
 
 	guint32 my_playerid;
 	gboolean i_am_the_master;
@@ -266,9 +265,9 @@ typedef struct {
 	gchar   *host;
 	gint32  port;
 	guint32 socket;
-	guchar  *server_version;
+	gchar  *server_version;
 
-	guchar *buffer_in;
+	gchar *buffer_in;
 
 } _connect;
 
@@ -326,15 +325,15 @@ typedef struct {
 
 	gboolean open;
 
-	guchar *path;
-	guchar *path_preview;
-	guchar *path_conf;
+	gchar *path;
+	gchar *path_preview;
+	gchar *path_conf;
 
-	guchar *name;
-	guchar *type;
-	guchar *version;
-	guchar *author;
-	guchar *email;
+	gchar *name;
+	gchar *type;
+	gchar *version;
+	gchar *author;
+	gchar *email;
 
 } _theme;
 
@@ -346,65 +345,65 @@ typedef struct {
 typedef struct  {
 
 	/* pngfile logo */
-	guchar  *pngfile_logo_filename;
+	gchar  *pngfile_logo_filename;
 	gboolean pngfile_logo_need_alpha;
-	guchar  *pngfile_logo_image, *pngfile_logo_alpha;
+	guint8  *pngfile_logo_image, *pngfile_logo_alpha;
 
 	/* pngfile board */
-	guchar  *pngfile_board_filename;
+	gchar  *pngfile_board_filename;
 	gboolean pngfile_board_need_alpha;
 	guint16  pngfile_board_x[MAX_ESTATES],     pngfile_board_y[MAX_ESTATES];
 	guint16  pngfile_board_width[MAX_ESTATES], pngfile_board_height[MAX_ESTATES];
-	guchar  *pngfile_board_image[MAX_ESTATES];
+	guint8  *pngfile_board_image[MAX_ESTATES];
 
 	/* pngfile_tokens */
-	guchar  *pngfile_token_filename;
+	gchar  *pngfile_token_filename;
 	gboolean pngfile_token_need_alpha;
 	guint16  pngfile_token_x[MAX_PLAYERS],      pngfile_token_y[MAX_PLAYERS];
 	guint16  pngfile_token_width[MAX_PLAYERS],  pngfile_token_height[MAX_PLAYERS];
-	guchar  *pngfile_token_image[MAX_PLAYERS], *pngfile_token_alpha[MAX_PLAYERS];
+	guint8  *pngfile_token_image[MAX_PLAYERS], *pngfile_token_alpha[MAX_PLAYERS];
 
 	/* pngfile_stars */
-	guchar  *pngfile_star_filename;
+	gchar  *pngfile_star_filename;
 	gboolean pngfile_star_need_alpha;
 	guint16  pngfile_star_x[MAX_PLAYERS],      pngfile_star_y[MAX_PLAYERS];
 	guint16  pngfile_star_width[MAX_PLAYERS],  pngfile_star_height[MAX_PLAYERS];
-	guchar  *pngfile_star_image[MAX_PLAYERS], *pngfile_star_alpha[MAX_PLAYERS];
+	guint8  *pngfile_star_image[MAX_PLAYERS], *pngfile_star_alpha[MAX_PLAYERS];
 
 	/* pngfile_stars_m (mortgaged) */
-	guchar  *pngfile_star_m_filename;
+	gchar  *pngfile_star_m_filename;
 	gboolean pngfile_star_m_need_alpha;
 	guint16  pngfile_star_m_x[MAX_PLAYERS],      pngfile_star_m_y[MAX_PLAYERS];
 	guint16  pngfile_star_m_width[MAX_PLAYERS],  pngfile_star_m_height[MAX_PLAYERS];
-	guchar  *pngfile_star_m_image[MAX_PLAYERS], *pngfile_star_m_alpha[MAX_PLAYERS];
+	guint8  *pngfile_star_m_image[MAX_PLAYERS], *pngfile_star_m_alpha[MAX_PLAYERS];
 
 	/* pngfile_cards */
-	guchar  *pngfile_card_filename;
+	gchar  *pngfile_card_filename;
 	gboolean pngfile_card_need_alpha;
 	guint16  pngfile_card_x[MAX_PLAYERLIST_CARDS],     pngfile_card_y[MAX_PLAYERLIST_CARDS];
 	guint16  pngfile_card_width[MAX_PLAYERLIST_CARDS], pngfile_card_height[MAX_PLAYERLIST_CARDS];
-	guchar  *pngfile_card_image[MAX_PLAYERLIST_CARDS];
+	guint8  *pngfile_card_image[MAX_PLAYERLIST_CARDS];
 
 	/* pngfile_commands */
-	guchar  *pngfile_command_filename;
+	gchar  *pngfile_command_filename;
 	gboolean pngfile_command_need_alpha;
 	guint16  pngfile_command_x[MAX_COMMANDS],      pngfile_command_y[MAX_COMMANDS];
 	guint16  pngfile_command_width[MAX_COMMANDS],  pngfile_command_height[MAX_COMMANDS];
-	guchar  *pngfile_command_image[MAX_COMMANDS], *pngfile_command_alpha[MAX_COMMANDS];
+	guint8  *pngfile_command_image[MAX_COMMANDS], *pngfile_command_alpha[MAX_COMMANDS];
 
 	/* pngfile_horiz_houses */
-	guchar  *pngfile_horiz_house_filename;
+	gchar  *pngfile_horiz_house_filename;
 	gboolean pngfile_horiz_house_need_alpha;
 	guint16  pngfile_horiz_house_x[MAX_HOUSES],      pngfile_horiz_house_y[MAX_HOUSES];
 	guint16  pngfile_horiz_house_width[MAX_HOUSES],  pngfile_horiz_house_height[MAX_HOUSES];
-	guchar  *pngfile_horiz_house_image[MAX_HOUSES], *pngfile_horiz_house_alpha[MAX_HOUSES];
+	guint8  *pngfile_horiz_house_image[MAX_HOUSES], *pngfile_horiz_house_alpha[MAX_HOUSES];
 
 	/* pngfile_vert_houses */
-	guchar  *pngfile_vert_house_filename;
+	gchar  *pngfile_vert_house_filename;
 	gboolean pngfile_vert_house_need_alpha;
 	guint16  pngfile_vert_house_x[MAX_HOUSES],      pngfile_vert_house_y[MAX_HOUSES];
 	guint16  pngfile_vert_house_width[MAX_HOUSES],  pngfile_vert_house_height[MAX_HOUSES];
-	guchar  *pngfile_vert_house_image[MAX_HOUSES], *pngfile_vert_house_alpha[MAX_HOUSES];
+	guint8  *pngfile_vert_house_image[MAX_HOUSES], *pngfile_vert_house_alpha[MAX_HOUSES];
 
 
 	/* load flags */
@@ -450,7 +449,7 @@ _data *data;
 #define PHASE_GAMEPLAY   5
 typedef struct  {
 
-	guchar *path_home;
+	gchar *path_home;
 
 	guint8 phase;
 
@@ -502,15 +501,15 @@ _global *global;
 #define GAME_PLAYERLIST_POS_RIGHT 1
 typedef struct  {
 
-	guchar   *nickname;
+	gchar   *nickname;
 
-	guchar   *metaserver_host;
+	gchar   *metaserver_host;
 	guint32   metaserver_port;
 	gboolean  metaserver_autogetlist;
 	gboolean  metaserver_autogetgames;
 	gboolean  metaserver_sendclientversion;
 
-	guchar   *getgames_host;
+	gchar   *getgames_host;
 	guint32   getgames_port;
 	gboolean  getgames_autogetgames;
 
