@@ -2,7 +2,7 @@
  *     gtkatlantic - the gtk+ monopd client, enjoy network monopoly games
  *
  *
- *  Copyright (C) 2002-2004 Rochet Sylvain
+ *  Copyright (C) 2002-2010 Rochet Sylvain
  *
  *  gtkatlantic is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -610,7 +610,7 @@ void interface_create_gameboardpage()  {
 	guint32  bg_color;
 
 	GtkWidget *MenuItem;
-
+	gint32 nb_players;
 
 	global->phase = PHASE_GAMEPLAY;
 	game_sort_playerlist_by_playerid();
@@ -844,12 +844,13 @@ void interface_create_gameboardpage()  {
 	game->BoxMessageAndChat = gtk_vbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(VerticalBoxPlayerlistMessageChat), game->BoxMessageAndChat, TRUE, TRUE, 0);
 
-	if(game->nb_players <= 5)  {
+	nb_players = game_nb_players();
+	if(nb_players <= 5)  {
 
 		game->message_float = 0;
 		game->chat_float = 0;
 	}
-	else if(game->nb_players <= 7)  {
+	else if(nb_players <= 7)  {
 
 		game->message_float = 0;
 		game->chat_float = 1;
@@ -1329,7 +1330,7 @@ void interface_create_message(GtkWidget *container)  {
 
 	//global->MessageBox;
 		//global->Message
-		GtkWidget* MessageVerticalScrollbar;
+		//GtkWidget* MessageVerticalScrollbar;
 
 	GtkTextBuffer *textbuff;
 	GtkTextIter textiter;
@@ -1631,7 +1632,7 @@ void interface_create_config_panel()  {
 		GtkWidget *Button;
 
 	GList *list;
-	guchar *text;
+	gchar *text;
 
 	if(global->ConfigWin)  return;
 
@@ -2026,7 +2027,7 @@ void interface_create_helpwin()  {
 				GtkTextIter textiter;
 
 	FILE *file;
-	guchar *filename, *data, *complete, *tmp;
+	gchar *filename, *data, *complete, *tmp;
 	gint32 len;
 
 	if(global->HelpWin)  return;
@@ -2140,7 +2141,7 @@ void gameclist_title_showservers()  {
 
 
 /* generic window with a label into */
-void interface_create_messagewin(guchar *msg)  {
+void interface_create_messagewin(gchar *msg)  {
 
 /*	GtkWidget *MessageWin;
 		GtkWidget *VBox;
@@ -2187,7 +2188,7 @@ void interface_create_messagewin(guchar *msg)  {
 /* when receive event: redraw an estate */
 void on_board_expose (GtkWidget *widget, GdkEventExpose *event)   {
 
-	guchar *ptr = gtk_object_get_data(GTK_OBJECT(widget), "estateid");
+	gchar *ptr = gtk_object_get_data(GTK_OBJECT(widget), "estateid");
 
 	game->estate[ atoi(ptr) ].redraw = TRUE;
 }
@@ -2195,7 +2196,7 @@ void on_board_expose (GtkWidget *widget, GdkEventExpose *event)   {
 /* when receive event: redraw player token */
 void on_playertoken_expose (GtkWidget *widget, GdkEventExpose *event)   {
 
-	guchar *ptr = gtk_object_get_data(GTK_OBJECT(widget), "player");
+	gchar *ptr = gtk_object_get_data(GTK_OBJECT(widget), "player");
 
 	global->player[ atoi(ptr) ].playerlist_token_redraw = TRUE;
 }
@@ -2203,7 +2204,7 @@ void on_playertoken_expose (GtkWidget *widget, GdkEventExpose *event)   {
 /* when receive event: redraw player cards */
 void on_playercards_expose (GtkWidget *widget, GdkEventExpose *event)   {
 
-	guchar *ptr = gtk_object_get_data(GTK_OBJECT(widget), "player");
+	gchar *ptr = gtk_object_get_data(GTK_OBJECT(widget), "player");
 
 	global->player[ atoi(ptr) ].playerlist_cards_redraw = TRUE;
 }
@@ -2240,7 +2241,7 @@ gboolean update_display() {
 /* update display of the theme page */
 void update_display_theme_preview()  {
 
-	guchar *ptr;
+	gchar *ptr;
 	GtkWidget *Preview;
 	guint32 width, height;
 
@@ -2253,7 +2254,7 @@ void update_display_theme_preview()  {
 		width = atoi( gtk_object_get_data(GTK_OBJECT(global->ThemeWin), "theme_preview_width") );
 		height = atoi( gtk_object_get_data(GTK_OBJECT(global->ThemeWin), "theme_preview_height") );
 
-		gdk_draw_rgb_image (Preview->window, Preview->style->fg_gc[GTK_STATE_NORMAL], 0, 0, width, height, GDK_RGB_DITHER_MAX, ptr, width * 3);
+		gdk_draw_rgb_image (Preview->window, Preview->style->fg_gc[GTK_STATE_NORMAL], 0, 0, width, height, GDK_RGB_DITHER_MAX, (guchar*)ptr, width * 3);
 		global->theme_redraw = FALSE;
 	}
 }
