@@ -2,7 +2,7 @@
  *     gtkatlantic - the gtk+ monopd client, enjoy network monopoly games
  *
  *
- *  Copyright (C) 2002-2004 Rochet Sylvain
+ *  Copyright (C) 2002-2010 Rochet Sylvain
  *
  *  gtkatlantic is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -39,9 +39,9 @@
 
 
 /* parse a config file */
-gboolean parse_file_config(guchar *filename)  {
+gboolean parse_file_config(gchar *filename)  {
 
-	guchar *str, *ident, *tmp;
+	gchar *str, *ident, *tmp;
 	struct stat s;
 	FILE *file;
 
@@ -72,19 +72,19 @@ gboolean parse_file_config(guchar *filename)  {
 			config->metaserver_host = tmp;
 
 			tmp = parser_get_data(str, "port");
-			config->metaserver_port = atoi( tmp );
+			config->metaserver_port = atoi( (gchar*)tmp );
 			g_free(tmp);
 
 			tmp = parser_get_data(str, "autogetgames");
-			config->metaserver_autogetgames = atoi( tmp );
+			config->metaserver_autogetgames = atoi( (gchar*)tmp );
 			g_free(tmp);
 
 			tmp = parser_get_data(str, "autogetlist");
-			config->metaserver_autogetlist = atoi( tmp );
+			config->metaserver_autogetlist = atoi( (gchar*)tmp );
 			g_free(tmp);
 
 			tmp = parser_get_data(str, "sendclientversion");
-			config->metaserver_sendclientversion = atoi( tmp );
+			config->metaserver_sendclientversion = atoi( (gchar*)tmp );
 			g_free(tmp);
 
 		} else if(! strcmp(ident, "anotherserver") )  {
@@ -94,38 +94,38 @@ gboolean parse_file_config(guchar *filename)  {
 			config->getgames_host = tmp;
 
 			tmp = parser_get_data(str, "port");
-			config->getgames_port = atoi( tmp );
+			config->getgames_port = atoi( (gchar*)tmp );
 			g_free(tmp);
 
 			tmp = parser_get_data(str, "autogetgames");
-			config->getgames_autogetgames = atoi( tmp );
+			config->getgames_autogetgames = atoi( (gchar*)tmp );
 			g_free(tmp);
 
 		} else if(! strcmp(ident, "buffer") )  {
 
 			tmp = parser_get_data(str, "message");
-			config->message_max_lines = atoi( tmp );
+			config->message_max_lines = atoi( (gchar*)tmp );
 			g_free(tmp);
 
 			tmp = parser_get_data(str, "chat");
-			config->chat_max_lines = atoi( tmp );
+			config->chat_max_lines = atoi( (gchar*)tmp );
 			g_free(tmp);
 
 		} else if(! strcmp(ident, "interface") )  {
 
 			tmp = parser_get_data(str, "playerlist");
-			if(! xmlStrcmp( tmp, "left") )
+			if(! strcmp( tmp, "left") )
 				config->game_playerlist_position = GAME_PLAYERLIST_POS_LEFT;
-			if(! xmlStrcmp( tmp, "right") )
+			if(! strcmp( tmp, "right") )
 				config->game_playerlist_position = GAME_PLAYERLIST_POS_RIGHT;
 			g_free(tmp);
 
 			tmp = parser_get_data(str, "token_speed");
-			config->game_token_animation_speed = atoi( tmp );
+			config->game_token_animation_speed = atoi( (gchar*)tmp );
 			g_free(tmp);
 
 			tmp = parser_get_data(str, "token_transparency");
-			config->game_token_transparency = atoi( tmp );
+			config->game_token_transparency = atoi( (gchar*)tmp );
 			g_free(tmp);
 		}
 
@@ -147,7 +147,8 @@ gboolean xmlparse_file_interface()  {
 	guint8 ident = 0xff;
 	guint32 color;
 	gint32 xoffset, yoffset;
-	guchar *filename, *tmp;
+	gchar *filename;
+	xmlChar *tmp;
 
 	filename = g_strconcat(PACKAGE_DATA_DIR, "/interface.xml", NULL);
 	doc = xmlParseFile(filename);
@@ -173,21 +174,21 @@ gboolean xmlparse_file_interface()  {
 		/* ==================== */
 
 		/* parse pngfile_logo */
-		if(! xmlStrcmp(cur->name, "pngfile_logo") )  {
+		if(! xmlStrcmp(cur->name, (xmlChar*)"pngfile_logo") )  {
 
-			data->pngfile_logo_filename = xmlGetProp(cur, "filename");
+			data->pngfile_logo_filename = (gchar*)xmlGetProp(cur, (xmlChar*)"filename");
 
-			tmp = xmlGetProp(cur, "need_alpha");
-			data->pngfile_logo_need_alpha = atoi( tmp );
+			tmp = xmlGetProp(cur, (xmlChar*)"need_alpha");
+			data->pngfile_logo_need_alpha = atoi( (gchar*)tmp );
 			g_free(tmp);
 
 			cur2 = cur->xmlChildrenNode;
 			do {
 
-				if(! xmlStrcmp(cur2->name, "buffer") )  {
+				if(! xmlStrcmp(cur2->name, (xmlChar*)"buffer") )  {
 
-					tmp = xmlGetProp(cur2, "id");
-					if( xmlStrcmp(tmp, "full")  )  g_free(data->pngfile_logo_filename);
+					tmp = xmlGetProp(cur2, (xmlChar*)"id");
+					if( xmlStrcmp(tmp, (xmlChar*)"full")  )  g_free(data->pngfile_logo_filename);
 					g_free(tmp);
 				}
 
@@ -196,37 +197,37 @@ gboolean xmlparse_file_interface()  {
 		}
 
 		/* parse pngfile_board */
-		if(! xmlStrcmp(cur->name, "pngfile_board") )  {
+		if(! xmlStrcmp(cur->name, (xmlChar*)"pngfile_board") )  {
 
-			data->pngfile_board_filename = xmlGetProp(cur, "filename");
+			data->pngfile_board_filename = (gchar*)xmlGetProp(cur, (xmlChar*)"filename");
 
-			tmp = xmlGetProp(cur, "need_alpha");
-			data->pngfile_board_need_alpha = atoi( tmp );
+			tmp = xmlGetProp(cur, (xmlChar*)"need_alpha");
+			data->pngfile_board_need_alpha = atoi( (gchar*)tmp );
 			g_free(tmp);
 
 			cur2 = cur->xmlChildrenNode;
 			do {
 
-				if(! xmlStrcmp(cur2->name, "buffer") )  {
+				if(! xmlStrcmp(cur2->name, (xmlChar*)"buffer") )  {
 
-					tmp = xmlGetProp(cur2, "id");
-					ident = atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"id");
+					ident = atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "x");
-					data->pngfile_board_x[ident]  = atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"x");
+					data->pngfile_board_x[ident]  = atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "y");
-					data->pngfile_board_y[ident]  = atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"y");
+					data->pngfile_board_y[ident]  = atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "width");
-					data->pngfile_board_width[ident]  = atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"width");
+					data->pngfile_board_width[ident]  = atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "height");
-					data->pngfile_board_height[ident] = atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"height");
+					data->pngfile_board_height[ident] = atoi( (gchar*)tmp );
 					g_free(tmp);
 				}
 
@@ -235,37 +236,37 @@ gboolean xmlparse_file_interface()  {
 		}
 
 		/* parse pngfile_tokens */
-		if(! xmlStrcmp(cur->name, "pngfile_tokens") )  {
+		if(! xmlStrcmp(cur->name, (xmlChar*)"pngfile_tokens") )  {
 
-			data->pngfile_token_filename = xmlGetProp(cur, "filename");
+			data->pngfile_token_filename = (gchar*)xmlGetProp(cur, (xmlChar*)"filename");
 
-			tmp = xmlGetProp(cur, "need_alpha");
-			data->pngfile_token_need_alpha = atoi( tmp );
+			tmp = xmlGetProp(cur, (xmlChar*)"need_alpha");
+			data->pngfile_token_need_alpha = atoi( (gchar*)tmp );
 			g_free(tmp);
 
 			cur2 = cur->xmlChildrenNode;
 			do {
 
-				if(! xmlStrcmp(cur2->name, "buffer") )  {
+				if(! xmlStrcmp(cur2->name, (xmlChar*)"buffer") )  {
 
-					tmp = xmlGetProp(cur2, "id");
-					ident = atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"id");
+					ident = atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "x");
-					data->pngfile_token_x[ident]  = atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"x");
+					data->pngfile_token_x[ident]  = atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "y");
-					data->pngfile_token_y[ident]  = atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"y");
+					data->pngfile_token_y[ident]  = atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "width");
-					data->pngfile_token_width[ident]  = atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"width");
+					data->pngfile_token_width[ident]  = atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "height");
-					data->pngfile_token_height[ident] = atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"height");
+					data->pngfile_token_height[ident] = atoi( (gchar*)tmp );
 					g_free(tmp);
 				}
 
@@ -274,37 +275,37 @@ gboolean xmlparse_file_interface()  {
 		}
 
 		/* parse pngfile_cards */
-		if(! xmlStrcmp(cur->name, "pngfile_cards") )  {
+		if(! xmlStrcmp(cur->name, (xmlChar*)"pngfile_cards") )  {
 
-			data->pngfile_card_filename = xmlGetProp(cur, "filename");
+			data->pngfile_card_filename = (gchar*)xmlGetProp(cur, (xmlChar*)"filename");
 
-			tmp = xmlGetProp(cur, "need_alpha");
-			data->pngfile_card_need_alpha = atoi( tmp );
+			tmp = xmlGetProp(cur, (xmlChar*)"need_alpha");
+			data->pngfile_card_need_alpha = atoi( (gchar*)tmp );
 			g_free(tmp);
 
 			cur2 = cur->xmlChildrenNode;
 			do {
 
-				if(! xmlStrcmp(cur2->name, "buffer") )  {
+				if(! xmlStrcmp(cur2->name, (xmlChar*)"buffer") )  {
 
-					tmp = xmlGetProp(cur2, "id");
-					ident = atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"id");
+					ident = atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "x");
-					data->pngfile_card_x[ident]  = atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"x");
+					data->pngfile_card_x[ident]  = atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "y");
-					data->pngfile_card_y[ident]  = atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"y");
+					data->pngfile_card_y[ident]  = atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "width");
-					data->pngfile_card_width[ident]  = atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"width");
+					data->pngfile_card_width[ident]  = atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "height");
-					data->pngfile_card_height[ident] = atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"height");
+					data->pngfile_card_height[ident] = atoi( (gchar*)tmp );
 					g_free(tmp);
 				}
 
@@ -313,37 +314,37 @@ gboolean xmlparse_file_interface()  {
 		}
 
 		/* parse pngfile_stars */
-		if(! xmlStrcmp(cur->name, "pngfile_stars") )  {
+		if(! xmlStrcmp(cur->name, (xmlChar*)"pngfile_stars") )  {
 
-			data->pngfile_star_filename = xmlGetProp(cur, "filename");
+			data->pngfile_star_filename = (gchar*)xmlGetProp(cur, (xmlChar*)"filename");
 
-			tmp = xmlGetProp(cur, "need_alpha");
-			data->pngfile_star_need_alpha = atoi( tmp );
+			tmp = xmlGetProp(cur, (xmlChar*)"need_alpha");
+			data->pngfile_star_need_alpha = atoi( (gchar*)tmp );
 			g_free(tmp);
 
 			cur2 = cur->xmlChildrenNode;
 			do {
 
-				if(! xmlStrcmp(cur2->name, "buffer") )  {
+				if(! xmlStrcmp(cur2->name, (xmlChar*)"buffer") )  {
 
-					tmp = xmlGetProp(cur2, "id");
-					ident = atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"id");
+					ident = atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "x");
-					data->pngfile_star_x[ident]  = atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"x");
+					data->pngfile_star_x[ident]  = atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "y");
-					data->pngfile_star_y[ident]  = atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"y");
+					data->pngfile_star_y[ident]  = atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "width");
-					data->pngfile_star_width[ident]  = atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"width");
+					data->pngfile_star_width[ident]  = atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "height");
-					data->pngfile_star_height[ident] = atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"height");
+					data->pngfile_star_height[ident] = atoi( (gchar*)tmp );
 					g_free(tmp);
 				}
 
@@ -352,37 +353,37 @@ gboolean xmlparse_file_interface()  {
 		}
 
 		/* parse pngfile_stars_m (mortgaged) */
-		if(! xmlStrcmp(cur->name, "pngfile_stars_m") )  {
+		if(! xmlStrcmp(cur->name, (xmlChar*)"pngfile_stars_m") )  {
 
-			data->pngfile_star_m_filename = xmlGetProp(cur, "filename");
+			data->pngfile_star_m_filename = (gchar*)xmlGetProp(cur, (xmlChar*)"filename");
 
-			tmp = xmlGetProp(cur, "need_alpha");
-			data->pngfile_star_m_need_alpha = atoi( tmp );
+			tmp = xmlGetProp(cur, (xmlChar*)"need_alpha");
+			data->pngfile_star_m_need_alpha = atoi( (gchar*)tmp );
 			g_free(tmp);
 
 			cur2 = cur->xmlChildrenNode;
 			do {
 
-				if(! xmlStrcmp(cur2->name, "buffer") )  {
+				if(! xmlStrcmp(cur2->name, (xmlChar*)"buffer") )  {
 
-					tmp = xmlGetProp(cur2, "id");
-					ident = atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"id");
+					ident = atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "x");
-					data->pngfile_star_m_x[ident]  = atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"x");
+					data->pngfile_star_m_x[ident]  = atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "y");
-					data->pngfile_star_m_y[ident]  = atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"y");
+					data->pngfile_star_m_y[ident]  = atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "width");
-					data->pngfile_star_m_width[ident]  = atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"width");
+					data->pngfile_star_m_width[ident]  = atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "height");
-					data->pngfile_star_m_height[ident] = atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"height");
+					data->pngfile_star_m_height[ident] = atoi( (gchar*)tmp );
 					g_free(tmp);
 				}
 
@@ -391,37 +392,37 @@ gboolean xmlparse_file_interface()  {
 		}
 
 		/* parse pngfile_commands */
-		if(! xmlStrcmp(cur->name, "pngfile_commands") )  {
+		if(! xmlStrcmp(cur->name, (xmlChar*)"pngfile_commands") )  {
 
-			data->pngfile_command_filename = xmlGetProp(cur, "filename");
+			data->pngfile_command_filename = (gchar*)xmlGetProp(cur, (xmlChar*)"filename");
 
-			tmp = xmlGetProp(cur, "need_alpha");
-			data->pngfile_command_need_alpha = atoi( tmp );
+			tmp = xmlGetProp(cur, (xmlChar*)"need_alpha");
+			data->pngfile_command_need_alpha = atoi( (gchar*)tmp );
 			g_free(tmp);
 
 			cur2 = cur->xmlChildrenNode;
 			do {
 
-				if(! xmlStrcmp(cur2->name, "buffer") )  {
+				if(! xmlStrcmp(cur2->name, (xmlChar*)"buffer") )  {
 
-					tmp = xmlGetProp(cur2, "id");
-					ident = atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"id");
+					ident = atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "x");
-					data->pngfile_command_x[ident]  = atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"x");
+					data->pngfile_command_x[ident]  = atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "y");
-					data->pngfile_command_y[ident]  = atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"y");
+					data->pngfile_command_y[ident]  = atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "width");
-					data->pngfile_command_width[ident]  = atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"width");
+					data->pngfile_command_width[ident]  = atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "height");
-					data->pngfile_command_height[ident] = atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"height");
+					data->pngfile_command_height[ident] = atoi( (gchar*)tmp );
 					g_free(tmp);
 				}
 
@@ -430,37 +431,37 @@ gboolean xmlparse_file_interface()  {
 		}
 
 		/* parse pngfile_horiz_houses */
-		if(! xmlStrcmp(cur->name, "pngfile_horiz_houses") )  {
+		if(! xmlStrcmp(cur->name, (xmlChar*)"pngfile_horiz_houses") )  {
 
-			data->pngfile_horiz_house_filename = xmlGetProp(cur, "filename");
+			data->pngfile_horiz_house_filename = (gchar*)xmlGetProp(cur, (xmlChar*)"filename");
 
-			tmp = xmlGetProp(cur, "need_alpha");
-			data->pngfile_horiz_house_need_alpha = atoi( tmp );
+			tmp = xmlGetProp(cur, (xmlChar*)"need_alpha");
+			data->pngfile_horiz_house_need_alpha = atoi( (gchar*)tmp );
 			g_free(tmp);
 
 			cur2 = cur->xmlChildrenNode;
 			do {
 
-				if(! xmlStrcmp(cur2->name, "buffer") )  {
+				if(! xmlStrcmp(cur2->name, (xmlChar*)"buffer") )  {
 
-					tmp = xmlGetProp(cur2, "id");
-					ident = atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"id");
+					ident = atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "x");
-					data->pngfile_horiz_house_x[ident]  = atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"x");
+					data->pngfile_horiz_house_x[ident]  = atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "y");
-					data->pngfile_horiz_house_y[ident]  = atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"y");
+					data->pngfile_horiz_house_y[ident]  = atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "width");
-					data->pngfile_horiz_house_width[ident]  = atoi( tmp );
+					tmp = xmlGetProp(cur2,(xmlChar*) "width");
+					data->pngfile_horiz_house_width[ident]  = atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "height");
-					data->pngfile_horiz_house_height[ident] = atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"height");
+					data->pngfile_horiz_house_height[ident] = atoi( (gchar*)tmp );
 					g_free(tmp);
 				}
 
@@ -469,37 +470,37 @@ gboolean xmlparse_file_interface()  {
 		}
 
 		/* parse pngfile_vert_houses */
-		if(! xmlStrcmp(cur->name, "pngfile_vert_houses") )  {
+		if(! xmlStrcmp(cur->name, (xmlChar*)"pngfile_vert_houses") )  {
 
-			data->pngfile_vert_house_filename = xmlGetProp(cur, "filename");
+			data->pngfile_vert_house_filename = (gchar*)xmlGetProp(cur, (xmlChar*)"filename");
 
-			tmp = xmlGetProp(cur, "need_alpha");
-			data->pngfile_vert_house_need_alpha = atoi( tmp );
+			tmp = xmlGetProp(cur, (xmlChar*)"need_alpha");
+			data->pngfile_vert_house_need_alpha = atoi( (gchar*)tmp );
 			g_free(tmp);
 
 			cur2 = cur->xmlChildrenNode;
 			do {
 
-				if(! xmlStrcmp(cur2->name, "buffer") )  {
+				if(! xmlStrcmp(cur2->name, (xmlChar*)"buffer") )  {
 
-					tmp = xmlGetProp(cur2, "id");
-					ident = atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"id");
+					ident = atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "x");
-					data->pngfile_vert_house_x[ident]  = atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"x");
+					data->pngfile_vert_house_x[ident]  = atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "y");
-					data->pngfile_vert_house_y[ident]  = atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"y");
+					data->pngfile_vert_house_y[ident]  = atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "width");
-					data->pngfile_vert_house_width[ident]  = atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"width");
+					data->pngfile_vert_house_width[ident]  = atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "height");
-					data->pngfile_vert_house_height[ident] = atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"height");
+					data->pngfile_vert_house_height[ident] = atoi( (gchar*)tmp );
 					g_free(tmp);
 				}
 
@@ -512,92 +513,92 @@ gboolean xmlparse_file_interface()  {
 		/* ===================== */
 
 		/* parse board interface data */
-		if(! xmlStrcmp(cur->name, "display_board") )  {
+		if(! xmlStrcmp(cur->name, (xmlChar*)"display_board") )  {
 
 			data->number_estates = 0;
 
-			tmp = xmlGetProp(cur, "width");
-			data->board_width = atoi( tmp );
+			tmp = xmlGetProp(cur, (xmlChar*)"width");
+			data->board_width = atoi( (gchar*)tmp );
 			g_free(tmp);
 
-			tmp = xmlGetProp(cur, "height");
-			data->board_height = atoi( tmp );
+			tmp = xmlGetProp(cur, (xmlChar*)"height");
+			data->board_height = atoi( (gchar*)tmp );
 			g_free(tmp);
 
 			cur2 = cur->xmlChildrenNode;
 
 			do {
 
-				if(! xmlStrcmp(cur2->name, "estate") )  {
+				if(! xmlStrcmp(cur2->name, (xmlChar*)"estate") )  {
 
-					tmp = xmlGetProp(cur2, "id");
-					ident = atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"id");
+					ident = atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "x");
-					data->estate[ident].x = atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"x");
+					data->estate[ident].x = atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "y");
-					data->estate[ident].y = atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"y");
+					data->estate[ident].y = atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "buffer_board");
-					data->estate[ident].buffer_board = atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"buffer_board");
+					data->estate[ident].buffer_board = atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "x1token");
-					data->estate[ident].x1token = data->estate[ident].x + atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"x1token");
+					data->estate[ident].x1token = data->estate[ident].x + atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "y1token");
-					data->estate[ident].y1token = data->estate[ident].y + atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"y1token");
+					data->estate[ident].y1token = data->estate[ident].y + atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "x2token");
-					data->estate[ident].x2token = data->estate[ident].x + atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"x2token");
+					data->estate[ident].x2token = data->estate[ident].x + atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "y2token");
-					data->estate[ident].y2token = data->estate[ident].y + atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"y2token");
+					data->estate[ident].y2token = data->estate[ident].y + atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "x1jail");
-					data->estate[ident].x1jail = data->estate[ident].x + atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"x1jail");
+					data->estate[ident].x1jail = data->estate[ident].x + atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "y1jail");
-					data->estate[ident].y1jail = data->estate[ident].y + atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"y1jail");
+					data->estate[ident].y1jail = data->estate[ident].y + atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "x2jail");
-					data->estate[ident].x2jail = data->estate[ident].x + atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"x2jail");
+					data->estate[ident].x2jail = data->estate[ident].x + atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "y2jail");
-					data->estate[ident].y2jail = data->estate[ident].y + atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"y2jail");
+					data->estate[ident].y2jail = data->estate[ident].y + atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "xstar");
-					data->estate[ident].xstar = data->estate[ident].x + atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"xstar");
+					data->estate[ident].xstar = data->estate[ident].x + atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "ystar");
-					data->estate[ident].ystar = data->estate[ident].y + atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"ystar");
+					data->estate[ident].ystar = data->estate[ident].y + atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "xhouse");
-					data->estate[ident].xhouse = data->estate[ident].x + atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"xhouse");
+					data->estate[ident].xhouse = data->estate[ident].x + atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "yhouse");
-					data->estate[ident].yhouse = data->estate[ident].y + atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"yhouse");
+					data->estate[ident].yhouse = data->estate[ident].y + atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "type_house");
-					if(! xmlStrcmp(tmp, "horizontal") )
+					tmp = xmlGetProp(cur2, (xmlChar*)"type_house");
+					if(! xmlStrcmp(tmp, (xmlChar*)"horizontal") )
 						data->estate[ident].type_house = TYPE_HOUSE_HORIZONTAL;
-					else if(! xmlStrcmp(tmp, "vertical") )
+					else if(! xmlStrcmp(tmp, (xmlChar*)"vertical") )
 						data->estate[ident].type_house = TYPE_HOUSE_VERTICAL;
 					else
 						data->estate[ident].type_house = TYPE_HOUSE_NONE;
@@ -611,89 +612,89 @@ gboolean xmlparse_file_interface()  {
 		}
 
 		/* parse player token interface data */
-		if(! xmlStrcmp(cur->name, "display_playertoken") )  {
+		if(! xmlStrcmp(cur->name, (xmlChar*)"display_playertoken") )  {
 
-			tmp = xmlGetProp(cur, "width");
-			data->playerlist_token_width = atoi( tmp );
+			tmp = xmlGetProp(cur, (xmlChar*)"width");
+			data->playerlist_token_width = atoi( (gchar*)tmp );
 			g_free(tmp);
 
-			tmp = xmlGetProp(cur, "height");
-			data->playerlist_token_height = atoi( tmp );
+			tmp = xmlGetProp(cur, (xmlChar*)"height");
+			data->playerlist_token_height = atoi( (gchar*)tmp );
 			g_free(tmp);
 
-			tmp = xmlGetProp(cur, "bgcolor");
-			if( atoi( tmp ) < 0 )
+			tmp = xmlGetProp(cur, (xmlChar*)"bgcolor");
+			if( atoi( (gchar*)tmp ) < 0 )
 				data->playerlist_token_bgcolor = -1;
 			else  {
-				sscanf(tmp, "0x%6X", &color);
+				sscanf((gchar*)tmp, "0x%6X", &color);
 				data->playerlist_token_bgcolor = color;
 			}
 			g_free(tmp);
 		}
 
 		/* parse player cards interface data */
-		if(! xmlStrcmp(cur->name, "display_playercard") )  {
+		if(! xmlStrcmp(cur->name, (xmlChar*)"display_playercard") )  {
 
 			data->number_playerlist_card = 0;
 
-			tmp = xmlGetProp(cur, "width");
-			data->playerlist_cards_width = atoi( tmp );
+			tmp = xmlGetProp(cur, (xmlChar*)"width");
+			data->playerlist_cards_width = atoi( (gchar*)tmp );
 			g_free(tmp);
 
-			tmp = xmlGetProp(cur, "height");
-			data->playerlist_cards_height = atoi( tmp );
+			tmp = xmlGetProp(cur, (xmlChar*)"height");
+			data->playerlist_cards_height = atoi( (gchar*)tmp );
 			g_free(tmp);
 
-			tmp = xmlGetProp(cur, "xoffset");
-			xoffset = atoi( tmp );
+			tmp = xmlGetProp(cur, (xmlChar*)"xoffset");
+			xoffset = atoi( (gchar*)tmp );
 			g_free(tmp);
 
-			tmp = xmlGetProp(cur, "yoffset");
-			yoffset = atoi( tmp );
+			tmp = xmlGetProp(cur, (xmlChar*)"yoffset");
+			yoffset = atoi( (gchar*)tmp );
 			g_free(tmp);
 
-			tmp = xmlGetProp(cur, "alphaunowned");
-			if(! g_strncasecmp(tmp, "0x", 2) )  {
+			tmp = xmlGetProp(cur, (xmlChar*)"alphaunowned");
+			if(! g_strncasecmp((gchar*)tmp, "0x", 2) )  {
 
-				sscanf(tmp, "0x%2X", &color);
+				sscanf((gchar*)tmp, "0x%2X", &color);
 				data->playerlist_cards_alphaunowned = color;
 			}
-			else data->playerlist_cards_alphaunowned = atoi( tmp );
+			else data->playerlist_cards_alphaunowned = atoi( (gchar*)tmp );
 			g_free(tmp);
 
-			tmp = xmlGetProp(cur, "alphaowned");
-			if(! g_strncasecmp(tmp, "0x", 2) )  {
+			tmp = xmlGetProp(cur, (xmlChar*)"alphaowned");
+			if(! g_strncasecmp((gchar*)tmp, "0x", 2) )  {
 
-				sscanf(tmp, "0x%2X", &color);
+				sscanf((gchar*)tmp, "0x%2X", &color);
 				data->playerlist_cards_alphaowned = color;
 			}
-			else data->playerlist_cards_alphaowned = atoi( tmp );
+			else data->playerlist_cards_alphaowned = atoi( (gchar*)tmp );
 			g_free(tmp);
 
-			tmp = xmlGetProp(cur, "alphamortgage");
-			if(! g_strncasecmp(tmp, "0x", 2) )  {
+			tmp = xmlGetProp(cur, (xmlChar*)"alphamortgage");
+			if(! g_strncasecmp((gchar*)tmp, "0x", 2) )  {
 
-				sscanf(tmp, "0x%2X", &color);
+				sscanf((gchar*)tmp, "0x%2X", &color);
 				data->playerlist_cards_alphamortgage = color;
 			}
-			else data->playerlist_cards_alphamortgage = atoi( tmp );
+			else data->playerlist_cards_alphamortgage = atoi( (gchar*)tmp );
 			g_free(tmp);
 
-			tmp = xmlGetProp(cur, "cardbgcolor");
-			sscanf(tmp, "0x%6X", &color);
+			tmp = xmlGetProp(cur, (xmlChar*)"cardbgcolor");
+			sscanf((gchar*)tmp, "0x%6X", &color);
 			data->playerlist_cards_cardbgcolor = color;
 			g_free(tmp);
 
-			tmp = xmlGetProp(cur, "cardbgcolormortgage");
-			sscanf(tmp, "0x%6X", &color);
+			tmp = xmlGetProp(cur, (xmlChar*)"cardbgcolormortgage");
+			sscanf((gchar*)tmp, "0x%6X", &color);
 			data->playerlist_cards_cardbgcolormortgage = color;
 			g_free(tmp);
 
-			tmp = xmlGetProp(cur, "bgcolor");
-			if( atoi(tmp) < 0 )
+			tmp = xmlGetProp(cur, (xmlChar*)"bgcolor");
+			if( atoi((gchar*)tmp) < 0 )
 				data->playerlist_cards_bgcolor = -1;
 			else  {
-				sscanf(tmp, "0x%6X", &color);
+				sscanf((gchar*)tmp, "0x%6X", &color);
 				data->playerlist_cards_bgcolor = color;
 			}
 			g_free(tmp);
@@ -702,30 +703,30 @@ gboolean xmlparse_file_interface()  {
 
 			do {
 
-				if(! xmlStrcmp(cur2->name, "card") )  {
+				if(! xmlStrcmp(cur2->name, (xmlChar*)"card") )  {
 
-					tmp = xmlGetProp(cur2, "id");
-					ident = atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"id");
+					ident = atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "x");
-					data->playerlist_card[ident].x = atoi( tmp ) + xoffset;
+					tmp = xmlGetProp(cur2, (xmlChar*)"x");
+					data->playerlist_card[ident].x = atoi( (gchar*)tmp ) + xoffset;
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "y");
-					data->playerlist_card[ident].y = atoi( tmp ) + yoffset;
+					tmp = xmlGetProp(cur2, (xmlChar*)"y");
+					data->playerlist_card[ident].y = atoi( (gchar*)tmp ) + yoffset;
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "z");
-					data->playerlist_card[ident].z = atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"z");
+					data->playerlist_card[ident].z = atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "buffer_card");
-					data->playerlist_card[ident].buffer_card = atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"buffer_card");
+					data->playerlist_card[ident].buffer_card = atoi( (gchar*)tmp );
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "estateid");
-					data->playerlist_card[ident].estateid = atoi( tmp );
+					tmp = xmlGetProp(cur2, (xmlChar*)"estateid");
+					data->playerlist_card[ident].estateid = atoi( (gchar*)tmp );
 					g_free(tmp);
 
 					data->number_playerlist_card++;
@@ -750,7 +751,7 @@ gboolean intro_load_pngs()   {
 	png_structp png_ptr;
 	png_infop info_ptr;
 	_png_imagedata png_imagedata;
-	guchar *filename;
+	gchar *filename;
 	FILE *infile;
 
 	if(data->png_intro_loaded)  return TRUE;
@@ -814,7 +815,7 @@ gboolean game_load_pngs()   {
 	png_structp png_ptr;
 	png_infop info_ptr;
 	_png_imagedata png_imagedata;
-	guchar *filename;
+	gchar *filename;
 	FILE *infile;
 	guint32 i;
 
