@@ -2,7 +2,7 @@
  *     gtkatlantic - the gtk+ monopd client, enjoy network monopoly games
  *
  *
- *  Copyright (C) 2002-2004 Rochet Sylvain
+ *  Copyright (C) 2002-2010 Rochet Sylvain
  *
  *  gtkatlantic is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@ void theme_build_database()   {
 
 	DIR *d;
 	struct dirent *dir;
-	guchar *path, *path2;
+	gchar *path, *path2;
 	guint32 i;
 
 	/* first free all the database */
@@ -133,14 +133,14 @@ void theme_del_entry(guint32 slot) {
 }
 
 
-void theme_add_entry(guchar *path)  {
+void theme_add_entry(gchar *path)  {
 
 	guint32 slot, area = 0;
-	guchar *path2, *str, *ident;
+	gchar *path2, *str, *ident;
 	struct stat s;
 	FILE *file;
 
-	guchar *name = 0, *type = 0, *version = 0, *author = 0, *email = 0, *preview = 0;
+	gchar *name = 0, *type = 0, *version = 0, *author = 0, *email = 0, *preview = 0;
 
 	/* get properties of this theme, name, author, preview file, ... */
 	path2 = g_strconcat(path, "theme.conf", NULL);
@@ -234,7 +234,7 @@ void theme_build_selection_win()  {
 				GtkWidget *PreviewFrame;
 
 	GtkWidget *tmp;
-	guchar *str;
+	gchar *str;
 
 	if(global->ThemeWin)  return;
 
@@ -418,7 +418,7 @@ void theme_preview_free()  {
 
 	GtkWidget *Alignment;
 	GtkWidget *Preview;
-	guchar *buf = 0;
+	gchar *buf = 0;
 
 	/* free all preview data */
 	Alignment = gtk_object_get_data(GTK_OBJECT(global->ThemeWin), "theme_preview_container");
@@ -437,7 +437,8 @@ void theme_display(gint32 themeid)  {
 	GtkWidget *Label;
 	GtkWidget *Alignment;
 	GtkWidget *Preview;
-	guchar *buf = 0, *tmp;
+	guint8 *buf = 0;
+	gchar *tmp;
 	guint32 width, height;
 
 	if(! data->theme[themeid].open)  return;
@@ -497,11 +498,11 @@ void theme_display(gint32 themeid)  {
 }
 
 
-guchar* theme_preview_read(gint32 themeid, guint32 *width, guint32 *height)  {
+guint8* theme_preview_read(gint32 themeid, guint32 *width, guint32 *height)  {
 
 	struct stat s;
-	guchar *path = data->theme[themeid].path_preview;
-	guchar *buf;
+	gchar *path = data->theme[themeid].path_preview;
+	guint8 *buf;
 
 	png_structp png_ptr;
 	png_infop info_ptr;
