@@ -2,7 +2,7 @@
  *     gtkatlantic - the gtk+ monopd client, enjoy network monopoly games
  *
  *
- *  Copyright (C) 2002-2004 Rochet Sylvain
+ *  Copyright (C) 2002-2010 Rochet Sylvain
  *
  *  gtkatlantic is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -34,10 +34,10 @@
 #include "callback.h"
 
 
-void trade_initnew(guint32 tradeid)  {
+void trade_initnew(gint32 tradeid)  {
 
-	guint32 tradeslot;
-	guchar *sendstr;
+	gint32 tradeslot;
+	gchar *sendstr;
 
 	/* already created */
 	if(get_trade_slot_with_tradeid(tradeid) >= 0)  return;
@@ -58,7 +58,7 @@ void trade_initnew(guint32 tradeid)  {
 }
 
 
-void trade_destroy(guint32 tradeid)  {
+void trade_destroy(gint32 tradeid)  {
 
 	gint32 tradeslot;
 
@@ -69,7 +69,7 @@ void trade_destroy(guint32 tradeid)  {
 }
 
 
-void trade_destroy_slot(guint32 tradeslot)  {
+void trade_destroy_slot(gint32 tradeslot)  {
 
 	if(!game->trade[tradeslot].open) return;
 
@@ -78,7 +78,7 @@ void trade_destroy_slot(guint32 tradeslot)  {
 }
 
 
-void trade_create_panel(guint32 tradeslot)  {
+void trade_create_panel(gint32 tradeslot)  {
 
 	GtkWidget *TradeWin;
 		GtkWidget *VBox;
@@ -92,7 +92,7 @@ void trade_create_panel(guint32 tradeslot)  {
 				GtkWidget *HBox_buttons;
 
 	GtkWidget *Button;
-	guchar *text;
+	gchar *text;
 
 	TradeWin = game->trade[tradeslot].TradeWin = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 	gtk_widget_set_usize(TradeWin, 500, 220);
@@ -203,7 +203,7 @@ void trade_create_panel(guint32 tradeslot)  {
 }
 
 
-void trade_rebuild_playerlist(guint32 tradeslot)  {
+void trade_rebuild_playerlist(gint32 tradeslot)  {
 
 	GtkWidget *PlayerCList;
 	gchar *txt[10];
@@ -249,7 +249,7 @@ void trade_rebuild_playerlist(guint32 tradeslot)  {
 }
 
 
-void trade_rebuild_component(guint32 tradeslot)  {
+void trade_rebuild_component(gint32 tradeslot)  {
 
 	GtkWidget *box;
 		GtkWidget *OptionMenu;
@@ -257,7 +257,7 @@ void trade_rebuild_component(guint32 tradeslot)  {
 			GtkWidget *MenuItem;
 
 	guint32 i;
-	guchar *text;
+	gchar *text;
 
 	game->trade[tradeslot].current_component = 0;
 
@@ -319,7 +319,7 @@ void trade_rebuild_component(guint32 tradeslot)  {
 }
 
 
-void trade_rebuild_subcomponent(guint32 tradeslot)  {
+void trade_rebuild_subcomponent(gint32 tradeslot)  {
 
 	GtkWidget *box;
 		GtkWidget *Label;
@@ -327,7 +327,7 @@ void trade_rebuild_subcomponent(guint32 tradeslot)  {
 		GtkWidget *Combo;
 		GtkWidget *Alignment;
 			GtkWidget *Button;
-	guchar *text;
+	gchar *text;
 	guint32 i;
 	GList *list;
 	gpointer item;
@@ -554,7 +554,7 @@ void trade_update_card(gint32 tradeid, gint32 cardid, gint32 targetplayer)  {
 	gchar *txt[10], **text[2];
 	gint32 row, tradeslot, test, i;
 	GtkWidget *ProposalCList;
-	guchar *cardname;
+	gchar *cardname;
 
 	tradeslot = get_trade_slot_with_tradeid(tradeid);
 	ProposalCList = game->trade[tradeslot].ProposalCList;
@@ -613,7 +613,7 @@ void trade_update_estate(gint32 tradeid, gint32 estateid, gint32 targetplayer)
 	gchar *txt[10], **text[2];
 	gint32 row, tradeslot, test, i;
 	GtkWidget *ProposalCList;
-	guchar *estatename;
+	gchar *estatename;
 
 	tradeslot = get_trade_slot_with_tradeid(tradeid);
 	ProposalCList = game->trade[tradeslot].ProposalCList;
@@ -666,7 +666,7 @@ void trade_update_money(gint32 tradeid, gint32 playerfrom, gint32 playerto, gint
 	gchar *txt[10], **text[2];
 	gint32 row, tradeslot, test, i;
 	GtkWidget *ProposalCList;
-	guchar *from, *to, *moneystr;
+	gchar *from, *to, *moneystr;
 
 	moneystr = g_strdup_printf("%d money", money);
 
