@@ -2,7 +2,7 @@
  *     gtkatlantic - the gtk+ monopd client, enjoy network monopoly games
  *
  *
- *  Copyright (C) 2002-2004 Rochet Sylvain
+ *  Copyright (C) 2002-2010 Rochet Sylvain
  *
  *  gtkatlantic is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -96,7 +96,7 @@ no-need	.pi
 */
 
 
-void xmlparse_getgamelist_plugger(guint32 connectid, guchar *buffer)  {
+void xmlparse_getgamelist_plugger(guint32 connectid, gchar *buffer)  {
 
 	xmlDocPtr doc;
 	xmlNodePtr cur;
@@ -122,8 +122,8 @@ void xmlparse_getgamelist_plugger(guint32 connectid, guchar *buffer)  {
 
 	for( cur = cur->xmlChildrenNode ; cur != NULL ; cur = cur -> next)  {
 
-		if(! xmlStrcmp(cur->name, "server") )  xmlparse_server(connectid, doc, cur);
-		if(! xmlStrcmp(cur->name, "updategamelist") )  xmlparse_updategamelist(connectid, doc, cur);
+		if(! xmlStrcmp(cur->name, (xmlChar*)"server") )  xmlparse_server(connectid, doc, cur);
+		if(! xmlStrcmp(cur->name, (xmlChar*)"updategamelist") )  xmlparse_updategamelist(connectid, doc, cur);
 	}
 
 	xmlFreeDoc(doc);
@@ -132,7 +132,7 @@ void xmlparse_getgamelist_plugger(guint32 connectid, guchar *buffer)  {
 
 
 
-void xmlparse_game_plugger(guint32 connectid, guchar *buffer)  {
+void xmlparse_game_plugger(guint32 connectid, gchar *buffer)  {
 
 	xmlDocPtr doc;
 	xmlNodePtr cur;
@@ -154,19 +154,19 @@ void xmlparse_game_plugger(guint32 connectid, guchar *buffer)  {
 
 	for(cur = cur->xmlChildrenNode ; cur != NULL ; cur = cur -> next)  {
 
-		if(! xmlStrcmp(cur->name, "gameupdate") )  xmlparse_gameupdate(connectid, doc, cur);
-		if(! xmlStrcmp(cur->name, "server") )  xmlparse_server(connectid, doc, cur);
-		if(! xmlStrcmp(cur->name, "client") )  xmlparse_client(connectid, doc, cur);
-		if(! xmlStrcmp(cur->name, "msg") )  xmlparse_message(connectid, doc, cur);
-		if(! xmlStrcmp(cur->name, "estateupdate") )  xmlparse_estateupdate(connectid, doc, cur);
-		if(! xmlStrcmp(cur->name, "playerupdate") )  xmlparse_playerupdate(connectid, doc, cur);
-		if(! xmlStrcmp(cur->name, "auctionupdate") )  xmlparse_auctionupdate(connectid, doc, cur);
-		if(! xmlStrcmp(cur->name, "display") )  xmlparse_display(connectid, doc, cur);
-		if(! xmlStrcmp(cur->name, "configupdate") )  xmlparse_configupdate(connectid, doc, cur);
-		if(! xmlStrcmp(cur->name, "tradeupdate") )  xmlparse_tradeupdate(connectid, doc, cur);
-		if(! xmlStrcmp(cur->name, "cardupdate") )  xmlparse_cardupdate(connectid, doc, cur);
-		if(! xmlStrcmp(cur->name, "estategroupupdate") )  xmlparse_estategroupupdate(connectid, doc, cur);
-		if(! xmlStrcmp(cur->name, "deleteplayer") )  xmlparse_deleteplayer(connectid, doc, cur);
+		if(! xmlStrcmp(cur->name, (xmlChar*)"gameupdate") )  xmlparse_gameupdate(connectid, doc, cur);
+		if(! xmlStrcmp(cur->name, (xmlChar*)"server") )  xmlparse_server(connectid, doc, cur);
+		if(! xmlStrcmp(cur->name, (xmlChar*)"client") )  xmlparse_client(connectid, doc, cur);
+		if(! xmlStrcmp(cur->name, (xmlChar*)"msg") )  xmlparse_message(connectid, doc, cur);
+		if(! xmlStrcmp(cur->name, (xmlChar*)"estateupdate") )  xmlparse_estateupdate(connectid, doc, cur);
+		if(! xmlStrcmp(cur->name, (xmlChar*)"playerupdate") )  xmlparse_playerupdate(connectid, doc, cur);
+		if(! xmlStrcmp(cur->name, (xmlChar*)"auctionupdate") )  xmlparse_auctionupdate(connectid, doc, cur);
+		if(! xmlStrcmp(cur->name, (xmlChar*)"display") )  xmlparse_display(connectid, doc, cur);
+		if(! xmlStrcmp(cur->name, (xmlChar*)"configupdate") )  xmlparse_configupdate(connectid, doc, cur);
+		if(! xmlStrcmp(cur->name, (xmlChar*)"tradeupdate") )  xmlparse_tradeupdate(connectid, doc, cur);
+		if(! xmlStrcmp(cur->name, (xmlChar*)"cardupdate") )  xmlparse_cardupdate(connectid, doc, cur);
+		if(! xmlStrcmp(cur->name, (xmlChar*)"estategroupupdate") )  xmlparse_estategroupupdate(connectid, doc, cur);
+		if(! xmlStrcmp(cur->name, (xmlChar*)"deleteplayer") )  xmlparse_deleteplayer(connectid, doc, cur);
 	}
 
 	xmlFreeDoc(doc);
@@ -177,10 +177,10 @@ void xmlparse_game_plugger(guint32 connectid, guchar *buffer)  {
 
 void xmlparse_server(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 
-	guchar *tmp;
+	xmlChar *tmp;
 
-	tmp = xmlGetProp(cur, "version");
-	if(tmp)  connection[connectid]->server_version = tmp;
+	tmp = xmlGetProp(cur, (xmlChar*)"version");
+	if(tmp)  connection[connectid]->server_version = (gchar*)tmp;
 }
 
 
@@ -188,17 +188,17 @@ void xmlparse_server(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 
 void xmlparse_client(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 
-	guchar *tmp;
+	xmlChar *tmp;
 
-	tmp = xmlGetProp(cur, "playerid");
+	tmp = xmlGetProp(cur, (xmlChar*)"playerid");
 	if( tmp )  {
-		game->my_playerid = atoi( tmp );
+		game->my_playerid = atoi( (gchar*)tmp );
 		g_free(tmp);
 	}
 
-	tmp = xmlGetProp(cur, "cookie");
+	tmp = xmlGetProp(cur, (xmlChar*)"cookie");
 	if( tmp )  {
-		game_write_cookie( tmp );
+		game_write_cookie( (gchar*)tmp );
 		g_free(tmp);
 	}
 }
@@ -208,21 +208,29 @@ void xmlparse_client(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 
 void xmlparse_gameupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur) {
 
-	guchar *tmp;
+	xmlChar *tmp;
 	struct timeval tv;
 	guint32 i;
-
-	tmp = xmlGetProp(cur, "gameid");
+	gint32 gameid;
+	
+	tmp = xmlGetProp(cur, (xmlChar*)"gameid");
 	if(tmp)  {
-		game->gameid = atoi(tmp);
+		gameid = atoi((gchar*)tmp);
 		g_free(tmp);
 	}
 
-	tmp = xmlGetProp(cur, "status");
+	tmp = xmlGetProp(cur, (xmlChar*)"status");
 
 	if(! tmp) return;
 
-	if(! xmlStrcmp(tmp, "config") ) {
+	if( game->gameid && game->gameid != gameid) {
+		printf("gameid mismatch, this should not happen\n");
+		abort();
+	}
+	// We only get the status if we are in the game
+	game->gameid = gameid;
+
+	if(! xmlStrcmp(tmp, (xmlChar*)"config") ) {
 
 		if(game->status != GAME_STATUS_CONFIG)  {
 
@@ -231,7 +239,7 @@ void xmlparse_gameupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur) {
 		}
 	}
 
-	if(! xmlStrcmp(tmp, "init") )  {
+	if(! xmlStrcmp(tmp, (xmlChar*)"init") )  {
 
 		if(game->status != GAME_STATUS_INIT)  {
 
@@ -241,7 +249,7 @@ void xmlparse_gameupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur) {
 		}
 	}
 
-	if(! xmlStrcmp(tmp, "run") )  {
+	if(! xmlStrcmp(tmp, (xmlChar*)"run") )  {
 
 		if(game->status != GAME_STATUS_RUN)  {
 
@@ -253,7 +261,7 @@ void xmlparse_gameupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur) {
 		}
 	}
 
-	if(! xmlStrcmp(tmp, "end") )  {
+	if(! xmlStrcmp(tmp, (xmlChar*)"end") )  {
 
 		if(game->status != GAME_STATUS_END)  {
 
@@ -282,12 +290,12 @@ void xmlparse_message(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 
 	gchar *type, *text, *author, *value;
 
-	type = xmlGetProp(cur, "type");
+	type = (gchar*)xmlGetProp(cur, (xmlChar*)"type");
 
 	if(! g_strncasecmp(type, "chat", 4) )  {
 
-		author = xmlGetProp(cur, "author");
-		value = xmlGetProp(cur, "value");
+		author = (gchar*)xmlGetProp(cur, (xmlChar*)"author");
+		value = (gchar*)xmlGetProp(cur, (xmlChar*)"value");
 		if(value && author)  {
 
 			if(! strncmp("[ACTION]", value, 8) )
@@ -307,7 +315,7 @@ void xmlparse_message(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 	else {
 
 		g_strup( type );
-		value = xmlGetProp(cur, "value");
+		value = (gchar*)xmlGetProp(cur, (xmlChar*)"value");
 		text = g_strdup_printf("%s: %s", type, value);
 		text_insert_message(text, strlen(text));
 		g_free(text);
@@ -323,52 +331,52 @@ void xmlparse_message(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 void xmlparse_estateupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 
 	guint32 color[3], i;
-	gchar *key, *tmp;
+	xmlChar *tmp;
 	guint32 id, frame, pic, star;
 	gint32 t, u;
 	gboolean owner_mortgage_changed = FALSE;
 
-	tmp = xmlGetProp(cur, "estateid");
+	tmp = xmlGetProp(cur, (xmlChar*)"estateid");
 	if(!tmp)  return;
-	id = atoi( tmp );
+	id = atoi( (gchar*)tmp );
 	g_free(tmp);
 	if(id < 0) return;
 
-	tmp = xmlGetProp(cur, "name");
-	if(tmp)  game->estate[id].name = tmp;
+	tmp = xmlGetProp(cur, (xmlChar*)"name");
+	if(tmp)  game->estate[id].name = (gchar*)tmp;
 
-	tmp = xmlGetProp(cur, "color");
+	tmp = xmlGetProp(cur, (xmlChar*)"color");
 	if(tmp) {
 
-		sscanf(tmp, "#%2X%2X%2X", &color[0], &color[1], &color[2]);
+		sscanf((gchar*)tmp, "#%2X%2X%2X", &color[0], &color[1], &color[2]);
 		game->estate[id].color[0] = color[0];
 		game->estate[id].color[1] = color[1];
 		game->estate[id].color[2] = color[2];
 		g_free(tmp);
 	}
 
-	tmp = xmlGetProp(cur, "bgcolor");
+	tmp = xmlGetProp(cur, (xmlChar*)"bgcolor");
 	if(tmp) {
 
-		sscanf(tmp, "#%2X%2X%2X", &color[0], &color[1], &color[2]);
+		sscanf((gchar*)tmp, "#%2X%2X%2X", &color[0], &color[1], &color[2]);
 		game->estate[id].bgcolor[0] = color[0];
 		game->estate[id].bgcolor[1] = color[1];
 		game->estate[id].bgcolor[2] = color[2];
 		g_free(tmp);
 	}
 
-	tmp = xmlGetProp(cur, "owner");
+	tmp = xmlGetProp(cur, (xmlChar*)"owner");
 	if(tmp)  {
 
-		t = game->estate[id].owner = atoi(tmp);
+		t = game->estate[id].owner = atoi((gchar*)tmp);
 		g_free(tmp);
 		owner_mortgage_changed = TRUE;
 	}
 
-	tmp = xmlGetProp(cur, "mortgaged");
+	tmp = xmlGetProp(cur, (xmlChar*)"mortgaged");
 	if(tmp)  {
 
-		u = game->estate[id].mortgaged = atoi(tmp);
+		u = game->estate[id].mortgaged = atoi((gchar*)tmp);
 		g_free(tmp);
 		owner_mortgage_changed = TRUE;
 	}
@@ -455,10 +463,10 @@ void xmlparse_estateupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 		}
 	}
 
-	tmp = xmlGetProp(cur, "houses");
+	tmp = xmlGetProp(cur, (xmlChar*)"houses");
 	if(tmp)  {
 
-		t = game->estate[id].houses = atoi(tmp);
+		t = game->estate[id].houses = atoi((gchar*)tmp);
  		g_free(tmp);
 
 		frame = game->board_frame;
@@ -499,79 +507,79 @@ void xmlparse_estateupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 		}
 	}
 
-	tmp = xmlGetProp(cur, "houseprice");
+	tmp = xmlGetProp(cur, (xmlChar*)"houseprice");
 	if(tmp)  {
-		game->estate[id].houseprice = atoi(tmp);
+		game->estate[id].houseprice = atoi((gchar*)tmp);
 		g_free(tmp);
 	}
 
-	tmp = xmlGetProp(cur, "sellhouseprice");
+	tmp = xmlGetProp(cur, (xmlChar*)"sellhouseprice");
 	if(tmp)  {
-		game->estate[id].sellhouseprice = atoi(tmp);
+		game->estate[id].sellhouseprice = atoi((gchar*)tmp);
 		g_free(tmp);
 	}
 
-	tmp = xmlGetProp(cur, "mortgageprice");
+	tmp = xmlGetProp(cur, (xmlChar*)"mortgageprice");
 	if(tmp)  {
-		game->estate[id].mortgageprice = atoi(tmp);
+		game->estate[id].mortgageprice = atoi((gchar*)tmp);
 		g_free(tmp);
 	}
 
-	tmp = xmlGetProp(cur, "unmortgageprice");
+	tmp = xmlGetProp(cur, (xmlChar*)"unmortgageprice");
 	if(tmp)  {
-		game->estate[id].unmortgageprice = atoi(tmp);
+		game->estate[id].unmortgageprice = atoi((gchar*)tmp);
 		g_free(tmp);
 	}
 
-	tmp = xmlGetProp(cur, "group");
+	tmp = xmlGetProp(cur, (xmlChar*)"group");
 	if(tmp)  {
-		game->estate[id].group = atoi(tmp);
+		game->estate[id].group = atoi((gchar*)tmp);
 		g_free(tmp);
 	}
 
-	tmp = xmlGetProp(cur, "can_be_owned");
+	tmp = xmlGetProp(cur, (xmlChar*)"can_be_owned");
 	if(tmp)  {
-		game->estate[id].can_be_owned = atoi(tmp);
+		game->estate[id].can_be_owned = atoi((gchar*)tmp);
 		g_free(tmp);
 	}
 
-	tmp = xmlGetProp(cur, "can_toggle_mortgage");
+	tmp = xmlGetProp(cur, (xmlChar*)"can_toggle_mortgage");
 	if(tmp)  {
-		game->estate[id].can_toggle_mortgage = atoi(tmp);
+		game->estate[id].can_toggle_mortgage = atoi((gchar*)tmp);
 		g_free(tmp);
 	}
 
-	tmp = xmlGetProp(cur, "can_buy_houses");
+	tmp = xmlGetProp(cur, (xmlChar*)"can_buy_houses");
 	if(tmp)  {
-		game->estate[id].can_buy_houses = atoi(tmp);
+		game->estate[id].can_buy_houses = atoi((gchar*)tmp);
 		g_free(tmp);
 	}
 
-	tmp = xmlGetProp(cur, "can_sell_houses");
+	tmp = xmlGetProp(cur, (xmlChar*)"can_sell_houses");
 	if(tmp)  {
-		game->estate[id].can_sell_houses = atoi(tmp);
+		game->estate[id].can_sell_houses = atoi((gchar*)tmp);
 		g_free(tmp);
 	}
 
-	tmp = xmlGetProp(cur, "money");
+	tmp = xmlGetProp(cur, (xmlChar*)"money");
 	if(tmp)  {
-		game->estate[id].money = atoi(tmp);
+		game->estate[id].money = atoi((gchar*)tmp);
 		g_free(tmp);
 	}
 
-	tmp = xmlGetProp(cur, "price");
+	tmp = xmlGetProp(cur, (xmlChar*)"price");
 	if(tmp)  {
-		game->estate[id].price = atoi(tmp);
+		game->estate[id].price = atoi((gchar*)tmp);
 		g_free(tmp);
 	}
 
 	for(i = 0 ; i <= 5 ; i++) {
 
-		key = g_strdup_printf("rent%d", i);
+		xmlChar *key = (xmlChar*)g_strdup_printf("rent%d", i);
 		tmp = xmlGetProp(cur, key);
 
 		if(tmp)  {
-			game->estate[id].rent[i] = atoi(tmp);
+			game->estate[id].rent[i] = atoi((gchar*)tmp);
 			g_free(tmp);
 		}
 		g_free(key);
@@ -584,15 +592,15 @@ void xmlparse_estateupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 void xmlparse_playerupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 
 	gint32 playerid, i;
-	gint8 id;
-	guchar *tmp;
+	gint32 id;
+	xmlChar *tmp;
 	GtkWidget *Combo, *StartButton, *Button;
 	GList *list;
 
 
-	tmp = xmlGetProp(cur, "playerid");
+	tmp = xmlGetProp(cur, (xmlChar*)"playerid");
 	if(!tmp) return;
-	playerid = atoi(tmp);
+ 	playerid = atoi((gchar*)tmp);
 	g_free(tmp);
 	if(!playerid) return;
 
@@ -606,32 +614,31 @@ void xmlparse_playerupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 
 			memset(&global->player[id], 0, sizeof(_player) );
 			global->player[id].playerid = playerid;
-			game->nb_players++;
 		}
 		else return;
 	}
 
 	if(id >= 0 && game->status > GAME_STATUS_CONFIG && global->player[id].game != game->gameid) return;
 
-	tmp = xmlGetProp(cur, "game");
+	tmp = xmlGetProp(cur, (xmlChar*)"game");
 	if(tmp)  {
-
-		global->player[id].game = atoi(tmp);
+	
+		global->player[id].game = atoi((gchar*)tmp);
 		g_free(tmp);
 	}
 
 
-	tmp = xmlGetProp(cur, "host");
+	tmp = xmlGetProp(cur, (xmlChar*)"host");
 	if(tmp)  {
 
 		if(global->player[id].host) g_free(global->player[id].host);
-		global->player[id].host = tmp;
+		global->player[id].host = (gchar*)tmp;
 	}
 
-	tmp = xmlGetProp(cur, "master");
+	tmp = xmlGetProp(cur, (xmlChar*)"master");
 	if(tmp)  {
 
-		global->player[id].master = atoi(tmp);
+		global->player[id].master = atoi((gchar*)tmp);
 		g_free(tmp);
 
 		if(global->player[id].master  &&  game->my_playerid == playerid)
@@ -647,18 +654,18 @@ void xmlparse_playerupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 		}
 	}
 
-	tmp = xmlGetProp(cur, "image");
+	tmp = xmlGetProp(cur, (xmlChar*)"image");
 	if(tmp)  {
 
 		if(global->player[id].image) g_free(global->player[id].image);
-		global->player[id].image = tmp;
+		global->player[id].image = (gchar*)tmp;
 	}
 
-	tmp = xmlGetProp(cur, "name");
+	tmp = xmlGetProp(cur, (xmlChar*)"name");
 	if(tmp)  {
 
 		if(global->player[id].name) g_free(global->player[id].name);
-		global->player[id].name = g_strndup(tmp, MAX_LENGTH_NICK);
+		global->player[id].name = g_strndup((gchar*)tmp, MAX_LENGTH_NICK);
 		g_free(tmp);
 
 		if(! strcmp(global->player[id].name, "_metaserver_"))  {
@@ -704,42 +711,42 @@ void xmlparse_playerupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 		}
 	}
 
-	tmp = xmlGetProp(cur, "money");
+	tmp = xmlGetProp(cur, (xmlChar*)"money");
 	if(tmp)  {
 
-		global->player[id].money = atoi(tmp);
+		global->player[id].money = atoi((gchar*)tmp);
 
 		if(global->player[id].playerlist_LabelMoneyPlayer)
-			gtk_label_set_text(GTK_LABEL(global->player[id].playerlist_LabelMoneyPlayer), tmp);
+			gtk_label_set_text(GTK_LABEL(global->player[id].playerlist_LabelMoneyPlayer), (gchar*)tmp);
 		g_free(tmp);
 	}
 
-	tmp = xmlGetProp(cur, "location");
+	tmp = xmlGetProp(cur, (xmlChar*)"location");
 	if(tmp)  {
 
-		global->player[id].location_to = atoi(tmp);
+		global->player[id].location_to = atoi((gchar*)tmp);
 		g_free(tmp);
 	}
 
-	tmp = xmlGetProp(cur, "jailed");
+	tmp = xmlGetProp(cur, (xmlChar*)"jailed");
 	if(tmp)  {
-		global->player[id].jailed = atoi(tmp);
+		global->player[id].jailed = atoi((gchar*)tmp);
 		g_free(tmp);
 
 		game_update_tokens();
 	}
 
-	tmp = xmlGetProp(cur, "directmove");
+	tmp = xmlGetProp(cur, (xmlChar*)"directmove");
 	if(tmp)  {
-		global->player[id].directmove = atoi(tmp);
+		global->player[id].directmove = atoi((gchar*)tmp);
 		g_free(tmp);
 
 		game_start_move_token(global->player[id].playerid);
 	}
 
-	tmp = xmlGetProp(cur, "bankrupt");
+	tmp = xmlGetProp(cur, (xmlChar*)"bankrupt");
 	if(tmp)  {
-		global->player[id].bankrupt = atoi(tmp);
+		global->player[id].bankrupt = atoi((gchar*)tmp);
 		g_free(tmp);
 
 		/* remove token */
@@ -747,9 +754,9 @@ void xmlparse_playerupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 			pic_unshow(game->board_frame, global->player[id].token_pic);
 	}
 
-	tmp = xmlGetProp(cur, "hasturn");
+	tmp = xmlGetProp(cur, (xmlChar*)"hasturn");
 	if(tmp)  {
-		global->player[id].hasturn = atoi(tmp);
+		global->player[id].hasturn = atoi((gchar*)tmp);
 		g_free(tmp);
 
 		/* set has turn attributes */
@@ -776,9 +783,9 @@ void xmlparse_playerupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 		}
 	}
 
-	tmp = xmlGetProp(cur, "can_roll");
+	tmp = xmlGetProp(cur, (xmlChar*)"can_roll");
 	if(tmp)  {
-		global->player[id].can_roll = atoi(tmp);
+		global->player[id].can_roll = atoi((gchar*)tmp);
 		g_free(tmp);
 
 		if(game->status == GAME_STATUS_RUN)  {
@@ -792,9 +799,9 @@ void xmlparse_playerupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 		}
 	}
 
-	tmp = xmlGetProp(cur, "can_buyestate");
+	tmp = xmlGetProp(cur, (xmlChar*)"can_buyestate");
 	if(tmp)  {
-		global->player[id].can_buyestate = atoi(tmp);
+		global->player[id].can_buyestate = atoi((gchar*)tmp);
 		g_free(tmp);
 	}
 
@@ -811,25 +818,27 @@ void xmlparse_auctionupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 	GtkTextIter textiter;
 	GtkTextMark *textmark;
 
-	guint32 actor = 0, auctionid, estateid, highbid = 0, highbidder, len, status;
-	guchar *ptr, *message, *tmp;
+	guint32 actor = 0, auctionid, estateid, highbid = 0, highbidder, status;
+	gchar *ptr, *message;
 
-	tmp = xmlGetProp(cur, "auctionid");
+	xmlChar *tmp;
+
+	tmp = xmlGetProp(cur, (xmlChar*)"auctionid");
 	if(!tmp) return;
-	auctionid = atoi(tmp);
+	auctionid = atoi((gchar*)tmp);
 	g_free(tmp);
 
 	/* initialise auction */
-	tmp = xmlGetProp(cur, "actor");
+	tmp = xmlGetProp(cur, (xmlChar*)"actor");
 	if(tmp)  {
-		actor = atoi(tmp);
+		actor = atoi((gchar*)tmp);
 		g_free(tmp);
 	}
 
-	tmp = xmlGetProp(cur, "estateid");
+	tmp = xmlGetProp(cur, (xmlChar*)"estateid");
 	if(tmp)  {
 
-		estateid = atoi(tmp);
+		estateid = atoi((gchar*)tmp);
 		g_free(tmp);
 
 		display_hide();
@@ -854,17 +863,17 @@ void xmlparse_auctionupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 	}
 
 	/* bid */
-	tmp = xmlGetProp(cur, "highbid");
+	tmp = xmlGetProp(cur, (xmlChar*)"highbid");
 	if(tmp)  {
-		highbid = atoi(tmp);
+		highbid = atoi((gchar*)tmp);
 		gtk_object_set_data(GTK_OBJECT(game->BoardCenter), "auction_highbid", GINT_TO_POINTER(highbid));
 		g_free(tmp);
 	}
 
-	tmp = xmlGetProp(cur, "highbidder");
+	tmp = xmlGetProp(cur, (xmlChar*)"highbidder");
 	if(tmp)  {
 
-		highbidder = atoi(tmp);
+		highbidder = atoi((gchar*)tmp);
 		g_free(tmp);
 
 		message = g_strdup_printf("%s bid %d", global->player[ get_player_slot_with_playerid(highbidder) ].name, highbid);
@@ -884,10 +893,10 @@ void xmlparse_auctionupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 	}
 
 	/* status */
-	tmp =  xmlGetProp(cur, "status");
+	tmp = xmlGetProp(cur, (xmlChar*)"status");
 	if(tmp)  {
 
-		status = atoi(tmp);
+		status = atoi((gchar*)tmp);
 		g_free(tmp);
 
 		switch( status )  {
@@ -940,39 +949,40 @@ void xmlparse_display(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 
 	xmlNodePtr cur2;
 	gint32 estateid;
-	guchar *tmp, *caption, *command;
+	xmlChar *tmp;
+	gchar *caption, *command;
 	gboolean enable;
 
 	if( game->status != GAME_STATUS_RUN)  return;
 
 	display_init();
 
-	tmp = xmlGetProp(cur, "cleartext");
+	tmp = xmlGetProp(cur, (xmlChar*)"cleartext");
 	if(tmp)  {
-		if( atoi(tmp) )  display_clear_text();
+		if( atoi((gchar*)tmp) )  display_clear_text();
 		g_free(tmp);
 	}
 
-	tmp = xmlGetProp(cur, "clearbuttons");
+	tmp = xmlGetProp(cur, (xmlChar*)"clearbuttons");
 	if(tmp)  {
-		if( atoi(tmp) )  display_clear_buttons();
+		if( atoi((gchar*)tmp) )  display_clear_buttons();
 		g_free(tmp);
 	}
 
-	tmp = xmlGetProp(cur, "estateid");
+	tmp = xmlGetProp(cur, (xmlChar*)"estateid");
 	if(tmp)   {
 
-		estateid = atoi(tmp);
+		estateid = atoi((gchar*)tmp);
 		g_free(tmp);
 
 		if(estateid < 0)  display_clear_title();
 		else  display_estate(estateid);
 	}
 
-	tmp = xmlGetProp(cur, "text");
+	tmp = xmlGetProp(cur, (xmlChar*)"text");
 	if(tmp)  {
 
-		if( strlen(tmp) > 0)  display_text(tmp);
+		if( strlen((gchar*)tmp) > 0)  display_text((gchar*)tmp);
 		g_free(tmp);
 	}
 
@@ -981,16 +991,16 @@ void xmlparse_display(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 
 		if(game->status == GAME_STATUS_END)  continue;
 
-		if(! xmlStrcmp(cur2->name, "button") )  {
+		if(! xmlStrcmp(cur2->name, (xmlChar*)"button") )  {
 
-			caption = xmlGetProp(cur2, "caption");
-			command = xmlGetProp(cur2, "command");
+			caption = (gchar*)xmlGetProp(cur2, (xmlChar*)"caption");
+			command = (gchar*)xmlGetProp(cur2, (xmlChar*)"command");
 
-			tmp = xmlGetProp(cur2, "enabled");
-			enable = atoi(tmp);
+			tmp = xmlGetProp(cur2, (xmlChar*)"enabled");
+			enable = atoi((gchar*)tmp);
 			g_free(tmp);
 
-			display_button(caption, command, enable);
+			display_button((gchar*)caption, (gchar*)command, enable);
 			g_free(caption);
 			g_free(command);
 		}
@@ -1004,29 +1014,30 @@ void xmlparse_configupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 
 	GtkWidget *CButton;
 	xmlNodePtr cur2;
-	guchar *text, *tmp, *title, *command;
+	gchar *text, *title, *command;
 	guint32 signalid;
+	xmlChar *tmp;
 
 	for( cur2 = cur->xmlChildrenNode ; cur2 != NULL ; cur2 = cur2 -> next)  {
 
-		if(! xmlStrcmp(cur2->name, "option") )  {
+		if(! xmlStrcmp(cur2->name, (xmlChar*)"option") )  {
 
-			tmp = xmlGetProp(cur2, "type");
+			tmp = xmlGetProp(cur2, (xmlChar*)"type");
 			if(!tmp)  continue;
-			if(xmlStrcmp(tmp, "bool") )  {
+			if(xmlStrcmp(tmp, (xmlChar*)"bool") )  {
 
 				g_free(tmp);
 				continue;
 			}
 			g_free(tmp);
 
-			command = xmlGetProp(cur2, "command");
+			command = (gchar*)xmlGetProp(cur2, (xmlChar*)"command");
 			if(!command)  continue;
 
 			/* create it if not created */
 			if(! gtk_object_get_data(GTK_OBJECT(game->GameConfigBox), command) )  {
 
-				title = xmlGetProp(cur2, "title");
+				title = (gchar*)xmlGetProp(cur2, (xmlChar*)"title");
 				if(!title)  continue;
 
 				CButton = gtk_check_button_new_with_label(title);
@@ -1050,14 +1061,14 @@ void xmlparse_configupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 			/* modify */
 			CButton = gtk_object_get_data(GTK_OBJECT(game->GameConfigBox), command);
 
-			tmp = xmlGetProp(cur2, "value");
+			tmp = xmlGetProp(cur2, (xmlChar*)"value");
 			if(tmp)   {
 
 				/* disconnect signal */
 				text = gtk_object_get_data(GTK_OBJECT(CButton), "signal");
 				gtk_signal_disconnect(GTK_OBJECT(CButton), atoi(text) );
 
-				if( atoi(tmp) )
+				if( atoi((gchar*)tmp) )
 					gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(CButton), TRUE);
 				else
 					gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(CButton), FALSE);
@@ -1070,10 +1081,10 @@ void xmlparse_configupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 				gtk_object_set_data_full(GTK_OBJECT(CButton), "signal", text, g_free);
 			}
 
-			tmp = xmlGetProp(cur2, "edit");
+			tmp = xmlGetProp(cur2, (xmlChar*)"edit");
 			if(tmp)   {
 
-				if( atoi(tmp) )
+				if( atoi((gchar*)tmp) )
 					gtk_widget_set_sensitive(CButton, TRUE);
 				else
 					gtk_widget_set_sensitive(CButton, FALSE);
@@ -1094,47 +1105,47 @@ void xmlparse_configupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 void xmlparse_tradeupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 
 	xmlNodePtr cur2;
-	guchar *tmp;
+	xmlChar *tmp;
 	guint32 tradeid = 0, playerid = 0, actor = 0, cardid = 0, estateid = 0;
 	guint32 targetplayer = 0, playerfrom = 0, playerto = 0, money = 0;
 	gboolean accept = FALSE;
 
 	if( game->status != GAME_STATUS_RUN)  return;
 
-	tmp = xmlGetProp(cur, "tradeid");
+	tmp = xmlGetProp(cur, (xmlChar*)"tradeid");
 	if(tmp)  {
-		tradeid = atoi(tmp);
+		tradeid = atoi((gchar*)tmp);
 		g_free(tmp);
 	}
 	else  return;
 
-	tmp = xmlGetProp(cur, "actor");
+	tmp = xmlGetProp(cur, (xmlChar*)"actor");
 	if(tmp)   {
-		actor = atoi(tmp);
+		actor = atoi((gchar*)tmp);
 		g_free(tmp);
 	}
 
-	tmp = xmlGetProp(cur, "type");
+	tmp = xmlGetProp(cur, (xmlChar*)"type");
 	if(tmp)  {
 
-		if(! xmlStrcmp(tmp, "rejected") )  {
+		if(! xmlStrcmp(tmp, (xmlChar*)"rejected") )  {
 			trade_destroy(tradeid);
 			g_free(tmp);
 			return;
 		}
 
-		if(! xmlStrcmp(tmp, "completed") )  {
+		if(! xmlStrcmp(tmp, (xmlChar*)"completed") )  {
 			trade_destroy(tradeid);
 			g_free(tmp);
 			return;
 		}
 
-		if(! xmlStrcmp(tmp, "accepted") )  {
+		if(! xmlStrcmp(tmp, (xmlChar*)"accepted") )  {
 			g_free(tmp);
 			return;
 		}
 
-		if(! xmlStrcmp(tmp, "new") )  {
+		if(! xmlStrcmp(tmp, (xmlChar*)"new") )  {
 			trade_initnew(tradeid);
 			g_free(tmp);
 		}
@@ -1146,17 +1157,17 @@ void xmlparse_tradeupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 	for(cur2 = cur->xmlChildrenNode ; cur2 != NULL ; cur2 = cur2 -> next)  {
 
 		/* -- player -- */
-		if(! xmlStrcmp(cur2->name, "tradeplayer") )  {
+		if(! xmlStrcmp(cur2->name, (xmlChar*)"tradeplayer") )  {
 
-			tmp = xmlGetProp(cur2, "playerid");
+			tmp = xmlGetProp(cur2, (xmlChar*)"playerid");
 			if(tmp)   {
-				playerid = atoi(tmp);
+				playerid = atoi((gchar*)tmp);
 				g_free(tmp);
 			}
 
-			tmp = xmlGetProp(cur2, "accept");
+			tmp = xmlGetProp(cur2, (xmlChar*)"accept");
 			if(tmp)   {
-				accept = atoi(tmp);
+				accept = atoi((gchar*)tmp);
 				g_free(tmp);
 			}
 
@@ -1164,17 +1175,17 @@ void xmlparse_tradeupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 		}
 
 		/* -- card -- */
-		if(! xmlStrcmp(cur2->name, "tradecard") )  {
+		if(! xmlStrcmp(cur2->name, (xmlChar*)"tradecard") )  {
 
-			tmp = xmlGetProp(cur2, "cardid");
+			tmp = xmlGetProp(cur2, (xmlChar*)"cardid");
 			if(tmp)   {
-				cardid = atoi(tmp);
+				cardid = atoi((gchar*)tmp);
 				g_free(tmp);
 			}
 
-			tmp = xmlGetProp(cur2, "targetplayer");
+			tmp = xmlGetProp(cur2, (xmlChar*)"targetplayer");
 			if(tmp)   {
-				targetplayer = atoi(tmp);
+				targetplayer = atoi((gchar*)tmp);
 				g_free(tmp);
 			}
 
@@ -1182,17 +1193,17 @@ void xmlparse_tradeupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 		}
 
 		/* -- estate -- */
-		if(! xmlStrcmp(cur2->name, "tradeestate") )  {
+		if(! xmlStrcmp(cur2->name, (xmlChar*)"tradeestate") )  {
 
-			tmp = xmlGetProp(cur2, "estateid");
+			tmp = xmlGetProp(cur2, (xmlChar*)"estateid");
 			if(tmp)   {
-				estateid = atoi(tmp);
+				estateid = atoi((gchar*)tmp);
 				g_free(tmp);
 			}
 
-			tmp = xmlGetProp(cur2, "targetplayer");
+			tmp = xmlGetProp(cur2, (xmlChar*)"targetplayer");
 			if(tmp)   {
-				targetplayer = atoi(tmp);
+				targetplayer = atoi((gchar*)tmp);
 				g_free(tmp);
 			}
 
@@ -1200,23 +1211,23 @@ void xmlparse_tradeupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 		}
 
 		/* -- money -- */
-		if(! xmlStrcmp(cur2->name, "trademoney") )  {
+		if(! xmlStrcmp(cur2->name, (xmlChar*)"trademoney") )  {
 
-			tmp = xmlGetProp(cur2, "playerfrom");
+			tmp = xmlGetProp(cur2, (xmlChar*)"playerfrom");
 			if(tmp)   {
-				playerfrom = atoi(tmp);
+				playerfrom = atoi((gchar*)tmp);
 				g_free(tmp);
 			}
 
-			tmp = xmlGetProp(cur2, "playerto");
+			tmp = xmlGetProp(cur2, (xmlChar*)"playerto");
 			if(tmp)   {
-				playerto = atoi(tmp);
+				playerto = atoi((gchar*)tmp);
 				g_free(tmp);
 			}
 
-			tmp = xmlGetProp(cur2, "money");
+			tmp = xmlGetProp(cur2, (xmlChar*)"money");
 			if(tmp)   {
-				money = atoi(tmp);
+				money = atoi((gchar*)tmp);
 				g_free(tmp);
 			}
 
@@ -1231,21 +1242,20 @@ void xmlparse_tradeupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 
 void xmlparse_cardupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 
-	guchar *tmp;
-	gint32 cardid = 0, owner = 0, i;
-	gint8 cardslot = 0;
+	xmlChar *tmp;
+	gint32 cardid = 0, owner = 0, i, cardslot = 0;
 
 	if( game->status != GAME_STATUS_RUN)  return;
 
-	tmp = xmlGetProp(cur, "cardid");
+	tmp = xmlGetProp(cur, (xmlChar*)"cardid");
 	if(tmp)  {
-		cardid = atoi(tmp);
+		cardid = atoi((gchar*)tmp);
 		g_free(tmp);
 	}
 
-	tmp = xmlGetProp(cur, "owner");
+	tmp = xmlGetProp(cur, (xmlChar*)"owner");
 	if(tmp)  {
-		owner = atoi(tmp);
+		owner = atoi((gchar*)tmp);
 		g_free(tmp);
 	}
 
@@ -1284,12 +1294,12 @@ void xmlparse_cardupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 
 void xmlparse_estategroupupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 
-	guchar *tmp;
+	xmlChar *tmp;
 	gint32 groupid = -1;
 
-	tmp = xmlGetProp(cur, "groupid");
+	tmp = xmlGetProp(cur, (xmlChar*)"groupid");
 	if(tmp)  {
-		groupid = atoi(tmp);
+		groupid = atoi((gchar*)tmp);
 		g_free(tmp);
 	}
 
@@ -1297,7 +1307,7 @@ void xmlparse_estategroupupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur
 
 	if(game->group[groupid].name)  g_free(game->group[groupid].name);
 
-	game->group[groupid].name = xmlGetProp(cur, "name");
+	game->group[groupid].name = (gchar*)xmlGetProp(cur, (xmlChar*)"name");
 }
 
 
@@ -1305,12 +1315,12 @@ void xmlparse_estategroupupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur
 
 void xmlparse_deleteplayer(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 
-	guchar *tmp;
+	xmlChar *tmp;
 	gint32 playerid = -1, id;
 
-	tmp = xmlGetProp(cur, "playerid");
+	tmp = xmlGetProp(cur, (xmlChar*)"playerid");
 	if(tmp)  {
-		playerid = atoi(tmp);
+		playerid = atoi((gchar*)tmp);
 		g_free(tmp);
 	}
 
@@ -1329,9 +1339,10 @@ void xmlparse_deleteplayer(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 
 void xmlparse_updategamelist(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 
-	gchar *type, *txt[10], *host, *port, *name, **text[2], *tmp;
+	gchar *txt[10], *host, *port, *name, **text[2];
 	gint32 id, test, i;
 	xmlNodePtr cur2;
+	xmlChar *type;
 
 	if(global->phase != PHASE_GETGAMES)  {
 
@@ -1339,10 +1350,10 @@ void xmlparse_updategamelist(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)
 		return;
 	}
 
-	type = xmlGetProp(cur, "type");
+	type = xmlGetProp(cur, (xmlChar*)"type");
 	if(!type) return;
 
-	if(! xmlStrcmp(type, "full") )  {
+	if(! xmlStrcmp(type, (xmlChar*)"full") )  {
 
 		gtk_clist_freeze(GTK_CLIST(global->GameCList));
 		gameclist_title_showgames();
@@ -1372,10 +1383,12 @@ void xmlparse_updategamelist(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)
 
 		for(cur2 = cur->xmlChildrenNode ; cur2 != NULL ; cur2 = cur2 -> next )  {
 
-			if(! xmlStrcmp(cur2->name, "game") )  {
+			if(! xmlStrcmp(cur2->name, (xmlChar*)"game") )  {
 
-				tmp = xmlGetProp(cur2, "canbejoined");
-				if(tmp  &&  atoi(tmp) == 0 )  {
+				xmlChar *tmp;
+				
+				tmp = xmlGetProp(cur2, (xmlChar*)"canbejoined");
+				if(tmp  &&  atoi((gchar*)tmp) == 0 )  {
 
 					g_free(tmp);
 					continue;
@@ -1383,8 +1396,8 @@ void xmlparse_updategamelist(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)
 				if(tmp) g_free(tmp);
 
 				/* ONLY TEMPORARLY ! */
-				tmp = xmlGetProp(cur2, "gametype");
-				if(xmlStrcmp(tmp, "city")  &&  xmlStrcmp(tmp, "french_city") )  {
+				tmp = xmlGetProp(cur2, (xmlChar*)"gametype");
+				if(xmlStrcmp(tmp, (xmlChar*)"city")  &&  xmlStrcmp(tmp, (xmlChar*)"french_city") )  {
 
 					g_free(tmp);
 					continue;
@@ -1392,11 +1405,11 @@ void xmlparse_updategamelist(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)
 
 				g_free(tmp);
 
-				tmp = xmlGetProp(cur2, "id");
-				id = atoi(tmp);
+				tmp = xmlGetProp(cur2, (xmlChar*)"id");
+				id = atoi((gchar*)tmp);
 				g_free(tmp);
 
-				name = xmlGetProp(cur2, "name");
+				name = (gchar*)xmlGetProp(cur2, (xmlChar*)"name");
 
 				txt[0] = g_strdup(host);
 				txt[1] = g_strdup(connection[connectid]->server_version);
@@ -1404,11 +1417,11 @@ void xmlparse_updategamelist(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)
 					txt[2] = g_strdup_printf("Create a new %s game", name);
 				else
 					txt[2] = g_strdup_printf("Join %s game #%d", name, id);
-				txt[3] = xmlGetProp(cur2, "description");
-				txt[4] = xmlGetProp(cur2, "players");
+				txt[3] = (gchar*)xmlGetProp(cur2, (xmlChar*)"description");
+				txt[4] = (gchar*)xmlGetProp(cur2, (xmlChar*)"players");
 				txt[5] = g_strdup(port);
-				txt[6] = xmlGetProp(cur2, "gametype");
-				txt[7] = xmlGetProp(cur2, "id");
+				txt[6] = (gchar*)xmlGetProp(cur2, (xmlChar*)"gametype");
+				txt[7] = (gchar*)xmlGetProp(cur2, (xmlChar*)"id");
 
 				gtk_clist_append(GTK_CLIST(global->GameCList), txt);
 
@@ -1431,10 +1444,10 @@ void xmlparse_updategamelist(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)
 
 
 
-void xmlparse_metaserver(guint32 connectid, guchar *buffer) {
+void xmlparse_metaserver(guint32 connectid, gchar *buffer) {
 
 	gchar *txt[10], *text;
-	guchar *tmp;
+	xmlChar *tmp;
 	xmlDocPtr doc;
 	xmlNodePtr cur, cur2;
 	guint32 i, do_close = TRUE;
@@ -1471,9 +1484,9 @@ void xmlparse_metaserver(guint32 connectid, guchar *buffer) {
 
 	for(cur = cur->xmlChildrenNode ; cur != NULL ; cur = cur -> next)  {
 
-		if(! xmlStrcmp(cur->name, "metaserver") )  {
+		if(! xmlStrcmp(cur->name, (xmlChar*)"metaserver") )  {
 
-			tmp = xmlGetProp(cur, "version");
+			tmp = xmlGetProp(cur, (xmlChar*)"version");
 			text = g_strdup_printf("Atlantic metaserver version %s", tmp);
 			g_free(tmp);
 			text_insert_message(text, strlen(text));
@@ -1482,9 +1495,9 @@ void xmlparse_metaserver(guint32 connectid, guchar *buffer) {
 			do_close = FALSE;
 		}
 
-		if(! xmlStrcmp(cur->name, "msg") )  {
+		if(! xmlStrcmp(cur->name, (xmlChar*)"msg") )  {
 
-			tmp = xmlGetProp(cur, "value");
+			tmp = xmlGetProp(cur, (xmlChar*)"value");
 			text = g_strdup_printf("%s", tmp);
 			g_free(tmp);
 			interface_create_messagewin(text);
@@ -1495,12 +1508,12 @@ void xmlparse_metaserver(guint32 connectid, guchar *buffer) {
 
 
 		if(connection[connectid]->type == CONNECT_TYPE_META_GETLIST
-			&& !xmlStrcmp(cur->name, "server") )  {
+			&& !xmlStrcmp(cur->name, (xmlChar*)"server") )  {
 
-			txt[0] = xmlGetProp(cur, "host");
-			txt[1] = xmlGetProp(cur, "port");
-			txt[2] = xmlGetProp(cur, "version");
-			txt[3] = xmlGetProp(cur, "users");
+			txt[0] = (gchar*)xmlGetProp(cur, (xmlChar*)"host");
+			txt[1] = (gchar*)xmlGetProp(cur, (xmlChar*)"port");
+			txt[2] = (gchar*)xmlGetProp(cur, (xmlChar*)"version");
+			txt[3] = (gchar*)xmlGetProp(cur, (xmlChar*)"users");
 			txt[4] = g_strdup("");
 			txt[5] = g_strdup("");
 			txt[6] = g_strdup("");
@@ -1513,20 +1526,20 @@ void xmlparse_metaserver(guint32 connectid, guchar *buffer) {
 		}
 
 		if(connection[connectid]->type == CONNECT_TYPE_META_GETGAME
-			&& !xmlStrcmp(cur->name, "servergamelist") )  {
+			&& !xmlStrcmp(cur->name, (xmlChar*)"servergamelist") )  {
 
-			guchar *host, *port, *version, *name;
+			gchar *host, *port, *version, *name;
 			gint32 id;
-			host = xmlGetProp(cur, "host");
-			port = xmlGetProp(cur, "port");
-			version = xmlGetProp(cur, "version");
+			host = (gchar*)xmlGetProp(cur, (xmlChar*)"host");
+			port = (gchar*)xmlGetProp(cur, (xmlChar*)"port");
+			version = (gchar*)xmlGetProp(cur, (xmlChar*)"version");
 
 			for(cur2 = cur->xmlChildrenNode ; cur2 != NULL ; cur2 = cur2 -> next )  {
 
-				if(! xmlStrcmp(cur2->name, "game") )  {
+				if(! xmlStrcmp(cur2->name, (xmlChar*)"game") )  {
 
-					tmp = xmlGetProp(cur2, "canbejoined");
-					if(tmp  &&  atoi(tmp) == 0 )  {
+					tmp = xmlGetProp(cur2, (xmlChar*)"canbejoined");
+					if(tmp  &&  atoi((gchar*)tmp) == 0 )  {
 
 						g_free(tmp);
 						continue;
@@ -1534,8 +1547,8 @@ void xmlparse_metaserver(guint32 connectid, guchar *buffer) {
 					if(tmp) g_free(tmp);
 
 					/* ONLY TEMPORARLY ! */
-					tmp = xmlGetProp(cur2, "gametype");
-					if(xmlStrcmp(tmp, "city")  &&  xmlStrcmp(tmp, "french_city") )  {
+					tmp = xmlGetProp(cur2, (xmlChar*)"gametype");
+					if(xmlStrcmp(tmp, (xmlChar*)"city")  &&  xmlStrcmp(tmp, (xmlChar*)"french_city") )  {
 
 						g_free(tmp);
 						continue;
@@ -1543,11 +1556,11 @@ void xmlparse_metaserver(guint32 connectid, guchar *buffer) {
 
 					g_free(tmp);
 
-					tmp = xmlGetProp(cur2, "id");
-					id = atoi(tmp);
+					tmp = xmlGetProp(cur2, (xmlChar*)"id");
+					id = atoi((gchar*)tmp);
 					g_free(tmp);
 
-					name = xmlGetProp(cur2, "name");
+					name = (gchar*)xmlGetProp(cur2, (xmlChar*)"name");
 
 					txt[0] = g_strdup(host);
 					txt[1] = g_strdup(version);
@@ -1555,11 +1568,11 @@ void xmlparse_metaserver(guint32 connectid, guchar *buffer) {
 						txt[2] = g_strdup_printf("Create a new %s game", name);
 					else
 						txt[2] = g_strdup_printf("Join %s game #%d", name, id);
-					txt[3] = xmlGetProp(cur2, "description");
-					txt[4] = xmlGetProp(cur2, "players");
+					txt[3] = (gchar*)xmlGetProp(cur2, (xmlChar*)"description");
+					txt[4] = (gchar*)xmlGetProp(cur2, (xmlChar*)"players");
 					txt[5] = g_strdup(port);
-					txt[6] = xmlGetProp(cur2, "gametype");
-					txt[7] = xmlGetProp(cur2, "id");
+					txt[6] = (gchar*)xmlGetProp(cur2, (xmlChar*)"gametype");
+					txt[7] = (gchar*)xmlGetProp(cur2, (xmlChar*)"id");
 
 					gtk_clist_append(GTK_CLIST(global->GameCList), txt);
 
